///////////////////////////////////////////////////////////////////////////////
//
//    File Name:  DDR_6TO1_16CHAN_RT_RX.v
//      Version:  1.0
//         Date:  08/07/06
//        Model:  XAPP860 LVDS Receiver Module
//
//      Company:  Xilinx, Inc.
//  Contributor:  APD Applications Group
//
//   Disclaimer:  XILINX IS PROVIDING THIS DESIGN, CODE, OR
//                INFORMATION "AS IS" SOLELY FOR USE IN DEVELOPING
//                PROGRAMS AND SOLUTIONS FOR XILINX DEVICES.  BY
//                PROVIDING THIS DESIGN, CODE, OR INFORMATION AS
//                ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE,
//                APPLICATION OR STANDARD, XILINX IS MAKING NO
//                REPRESENTATION THAT THIS IMPLEMENTATION IS FREE
//                FROM ANY CLAIMS OF INFRINGEMENT, AND YOU ARE
//                RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY
//                REQUIRE FOR YOUR IMPLEMENTATION.  XILINX
//                EXPRESSLY DISCLAIMS ANY WARRANTY WHATSOEVER WITH
//                RESPECT TO THE ADEQUACY OF THE IMPLEMENTATION,
//                INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
//                REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE
//                FROM CLAIMS OF INFRINGEMENT, IMPLIED WARRANTIES
//                OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
//                PURPOSE.
//
//                (c) Copyright 2006 Xilinx, Inc.
//                All rights reserved.
//
///////////////////////////////////////////////////////////////////////////////
// 
// Summary:
//
// The DDR_6TO1_16CHAN_RT_RX module contains all logic in the XAPP860 LVDS Receiver,
// including 16 channels of LVDS data, one channel of LVDS clock, an initial clock/data 
// alignment algorithm, a real-time clock/data alignment algorithm, a control circuit to share the alignment machines among
// all 16 data channels, and tap counters that keep track of the IDELAY tap
// setting of all data channels.
//  
//----------------------------------------------------------------

module DDR_6TO1_16CHAN_RT_RX
	(
	DATA_RX_P,
	DATA_RX_N,
	CLOCK_RX_P,
	CLOCK_RX_N,
	INC_PAD,
	DEC_PAD,
	DATA_FROM_ISERDES,
	RESET,
	IDLY_RESET,
	IDELAYCTRL_RESET,
	BITSLIP_PAD,
	CLK200,
	TAP_00,
	TAP_01,
	TAP_02,
	TAP_03,
	TAP_04,
	TAP_05,
	TAP_06,
	TAP_07,
	TAP_08,
	TAP_09,
	TAP_10,
	TAP_11,
	TAP_12,
	TAP_13,
	TAP_14,
	TAP_15,
	TAP_CLK,
	TRAINING_DONE,
	RXCLK,
	RXCLKDIV,
	IDELAY_READY,
	RT_MANUAL_DISABLE
	);

input	[15:0]	DATA_RX_P;		//SERIAL SIDE RX DATA (P)
input	[15:0]	DATA_RX_N;              //SERIAL SIDE RX DATA (N)
input		CLOCK_RX_P;		//FORWARDED CLOCK FROM TX (P)
input		CLOCK_RX_N;             //FORWARDED CLOCK FROM TX (N)
input		INC_PAD;		//MANUAL INCREMENT TO DATA DELAY
input		DEC_PAD;		//MANUAL DECREMENT TO DATA DELAY
input		RESET;			//RX DOMAIN RESET
input		IDLY_RESET;		//IDELAY TAP RESET
input		IDELAYCTRL_RESET;	//IDELAYCTRL CIRCUIT RESET
input		BITSLIP_PAD;		//MANUAL BITSLIP TO DATA
input		CLK200;			//200 MHZ REFERENCE CLOCK TO IDELAYCTRL				
input		RT_MANUAL_DISABLE;	//DISABLE REAL TIME WINDOW MONITORING

output	[95:0]	DATA_FROM_ISERDES;	//PARALLEL SIDE RX DATA
output	[5:0]	TAP_00;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_01;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_02;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_03;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_04;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_05;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_06;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_07;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_08;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_09;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_10;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_11;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_12;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_13;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_14;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_15;			//IDELAY TAP COUNT (0-63)
output	[5:0]	TAP_CLK;		//IDELAY TAP COUNT ON CLK CHANNEL (0-63)
output		TRAINING_DONE;		//ALIGNMENT OF ALL CHANNELS COMPLETE
output		RXCLK;			//FORWARDED CLOCK FROM TX (BUFIO OUTPUT)
output		RXCLKDIV;               //PARALLEL SIDE RX CLOCK (DIVIDED FROM RXCLK)
output		IDELAY_READY;		//FLAG INDICATING THAT IDELAYCTRL IS LOCKED

wire		CLOCK_RX_BUF;
wire	[15:0]	DATA_RX_BUF;
wire	[15:0]	DATA_RX_BUF_MON;
wire	[15:0]	DATA_RX_IDLY;
wire	[15:0]	DATA_RX_IDLY_MON;
wire	[95:0]	DATA_FROM_ISERDES_MON;
wire		CLOCK_RX_ISERDES_OUT;
wire		BITSLIP_FROM_MACHINE;
wire		ICE_FROM_MACHINE;
wire		INC_FROM_MACHINE;
wire		DATA_ALIGNED;
wire		DATA_ALIGNED_RT;
wire	[15:0]	SHIFT1;
wire	[15:0]	SHIFT2;
wire	[3:0]	CHAN_SEL;
wire	[3:0]	CHAN_SEL_RT;
wire		INC_MONITOR;
wire		ICE_MONITOR;
wire		INC_DATABUS;
wire		ICE_DATABUS;

reg	[3:0]	INC_CAPTURE;
reg	[3:0]	DEC_CAPTURE;
reg	[3:0]	BITSLIP_CAPTURE;
reg		INC_PULSE;
reg		DEC_PULSE;
reg		BITSLIP_PULSE;
reg	[20:0]	RESET_SM;
reg	[15:0]	BITSLIP_TO_ISERDES;
reg	[15:0]	ICE_TO_ISERDES;
reg	[15:0]	INC_TO_ISERDES;
reg	[15:0]	ICE_TO_ISERDES_RT;
reg	[15:0]	INC_TO_ISERDES_RT;
reg	[15:0]	ICE_TO_MONITOR_RT;
reg	[15:0]	INC_TO_MONITOR_RT;
reg	[5:0]	DATA_TO_MACHINE;
reg	[5:0]	DATA_TO_RT;
reg	[5:0]	MONITOR_TO_RT;

integer		I;

assign 		INC_DELAY =	INC_PULSE;
assign 		ICE_DELAY = 	INC_PULSE || DEC_PULSE;
assign		TAP_CLK = 	6'h00;			//CLOCK DELAY IS NOT ADJUSTED IN THIS REFERENCE DESIGN

//IDELAYCTRL MODULE
IDELAYCTRL RX_IDELAYCTRL(.RDY(IDELAY_READY), .REFCLK(CLK200), .RST(IDELAYCTRL_RESET));


//SOURCE SYNCHRONOUS CLOCK INPUT
IBUFDS #(
	.DIFF_TERM("TRUE"),
	.IOSTANDARD("LVDS_25")
) SOURCE_SYNC_CLOCK_IN
	(
	.O(CLOCK_RX_BUF), 
	.I(CLOCK_RX_P), 
	.IB(CLOCK_RX_N)
	);


//IDELAY IN CLOCK PATH
IODELAY #(
	.IDELAY_TYPE("FIXED"),
	.IDELAY_VALUE(0),
	.ODELAY_VALUE(0),
	.REFCLK_FREQUENCY(200.00),
	.HIGH_PERFORMANCE_MODE("TRUE")
) ISERDES_CLOCK_RX
	(
	.DATAOUT(CLOCK_RX_ISERDES_OUT),
	.IDATAIN(CLOCK_RX_BUF),
	.ODATAIN(1'b0),
	.DATAIN(1'b0),
	.T(),
	.CE(1'b0),
	.INC(1'b0),
	.C(1'b0),
	.RST(RESET)
	);

//CLOCK BUFFER FOR SERIAL SIDE CLOCK	
BUFIO RX_CLK_BUFIO
	(
	.O(RXCLK), 
	.I(CLOCK_RX_ISERDES_OUT)
	);

//CLOCK BUFFER/DIVIDER FOR PARALLEL SIDE CLOCK
BUFR #(
	.BUFR_DIVIDE("3")
) RX_CLK_BUFR
	(
	.O(RXCLKDIV), 
	.CE(1'b1), 
	.CLR(1'b0), 
	.I(CLOCK_RX_ISERDES_OUT)
	);


//CHANNEL SELECT LOGIC TO SHARE ALIGNMENT MACHINE RESOURCES IN ROUND ROBIN FASHION
always @(posedge RXCLKDIV) begin
case (CHAN_SEL)
	4'b0000: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[5:0];
			INC_TO_ISERDES <= {15'b000000000000000, INC_FROM_MACHINE};
			ICE_TO_ISERDES <= {15'b000000000000000, ICE_FROM_MACHINE};
			BITSLIP_TO_ISERDES <= {15'b000000000000000, BITSLIP_FROM_MACHINE};
			end
	
	4'b0001: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[11:6];
			INC_TO_ISERDES <= {14'b00000000000000, INC_FROM_MACHINE, 1'b0};
			ICE_TO_ISERDES <= {14'b00000000000000, ICE_FROM_MACHINE, 1'b0};
			BITSLIP_TO_ISERDES <= {14'b00000000000000, BITSLIP_FROM_MACHINE, 1'b0};
			end
	
	4'b0010: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[17:12];
			INC_TO_ISERDES <= {13'b0000000000000, INC_FROM_MACHINE, 2'b00};
			ICE_TO_ISERDES <= {13'b0000000000000, ICE_FROM_MACHINE, 2'b00};
			BITSLIP_TO_ISERDES <= {13'b0000000000000, BITSLIP_FROM_MACHINE, 2'b00};
			end
	
	4'b0011: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[23:18];
			INC_TO_ISERDES <= {12'b000000000000, INC_FROM_MACHINE, 3'b000};
			ICE_TO_ISERDES <= {12'b000000000000, ICE_FROM_MACHINE, 3'b000};
			BITSLIP_TO_ISERDES <= {12'b000000000000, BITSLIP_FROM_MACHINE, 3'b000};
			end
	
	4'b0100: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[29:24];
			INC_TO_ISERDES <= {11'b00000000000, INC_FROM_MACHINE, 4'b0000};
			ICE_TO_ISERDES <= {11'b00000000000, ICE_FROM_MACHINE, 4'b0000};
			BITSLIP_TO_ISERDES <= {11'b00000000000, BITSLIP_FROM_MACHINE, 4'b0000};
			end
	
	4'b0101: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[35:30];
			INC_TO_ISERDES <= {10'b0000000000, INC_FROM_MACHINE, 5'b00000};
			ICE_TO_ISERDES <= {10'b0000000000, ICE_FROM_MACHINE, 5'b00000};
			BITSLIP_TO_ISERDES <= {10'b0000000000, BITSLIP_FROM_MACHINE, 5'b00000};
			end
	
	4'b0110: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[41:36];
			INC_TO_ISERDES <= {9'b000000000, INC_FROM_MACHINE, 6'b000000};
			ICE_TO_ISERDES <= {9'b000000000, ICE_FROM_MACHINE, 6'b000000};
			BITSLIP_TO_ISERDES <= {9'b000000000, BITSLIP_FROM_MACHINE, 6'b000000};
			end
	
	4'b0111: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[47:42];
			INC_TO_ISERDES <= {8'b00000000, INC_FROM_MACHINE, 7'b0000000};
			ICE_TO_ISERDES <= {8'b00000000, ICE_FROM_MACHINE, 7'b0000000};
			BITSLIP_TO_ISERDES <= {8'b00000000, BITSLIP_FROM_MACHINE, 7'b0000000};
			end
			
	4'b1000: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[53:48];
			INC_TO_ISERDES <= {7'b0000000, INC_FROM_MACHINE, 8'b00000000};
			ICE_TO_ISERDES <= {7'b0000000, ICE_FROM_MACHINE, 8'b00000000};
			BITSLIP_TO_ISERDES <= {7'b0000000, BITSLIP_FROM_MACHINE, 8'b00000000};
			end
			
	4'b1001: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[59:54];
			INC_TO_ISERDES <= {6'b000000, INC_FROM_MACHINE, 9'b000000000};
			ICE_TO_ISERDES <= {6'b000000, ICE_FROM_MACHINE, 9'b000000000};
			BITSLIP_TO_ISERDES <= {6'b000000, BITSLIP_FROM_MACHINE, 9'b000000000};
			end
	
	4'b1010: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[65:60];
			INC_TO_ISERDES <= {5'b00000, INC_FROM_MACHINE, 10'b0000000000};
			ICE_TO_ISERDES <= {5'b00000, ICE_FROM_MACHINE, 10'b0000000000};
			BITSLIP_TO_ISERDES <= {5'b00000, BITSLIP_FROM_MACHINE, 10'b0000000000};
			end
	
	4'b1011: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[71:66];
			INC_TO_ISERDES <= {4'b0000, INC_FROM_MACHINE, 11'b00000000000};
			ICE_TO_ISERDES <= {4'b0000, ICE_FROM_MACHINE, 11'b00000000000};
			BITSLIP_TO_ISERDES <= {4'b0000, BITSLIP_FROM_MACHINE, 11'b00000000000};
			end
	
	4'b1100: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[77:72];
			INC_TO_ISERDES <= {3'b000, INC_FROM_MACHINE, 12'b000000000000};
			ICE_TO_ISERDES <= {3'b000, ICE_FROM_MACHINE, 12'b000000000000};
			BITSLIP_TO_ISERDES <= {3'b000, BITSLIP_FROM_MACHINE, 12'b000000000000};
			end
	
	4'b1101: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[83:78];
			INC_TO_ISERDES <= {2'b00, INC_FROM_MACHINE, 13'b0000000000000};
			ICE_TO_ISERDES <= {2'b00, ICE_FROM_MACHINE, 13'b0000000000000};
			BITSLIP_TO_ISERDES <= {2'b00, BITSLIP_FROM_MACHINE, 13'b0000000000000};
			end
			
	4'b1110: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[89:84];
			INC_TO_ISERDES <= {1'b0, INC_FROM_MACHINE, 14'b00000000000000};
			ICE_TO_ISERDES <= {1'b0, ICE_FROM_MACHINE, 14'b00000000000000};
			BITSLIP_TO_ISERDES <= {1'b0, BITSLIP_FROM_MACHINE, 14'b00000000000000};
			end
			
	4'b1111: 	begin
			DATA_TO_MACHINE <= DATA_FROM_ISERDES[95:90];
			INC_TO_ISERDES <= {INC_FROM_MACHINE, 15'b000000000000000};
			ICE_TO_ISERDES <= {ICE_FROM_MACHINE, 15'b000000000000000};
			BITSLIP_TO_ISERDES <= {BITSLIP_FROM_MACHINE, 15'b000000000000000};
			end
endcase
end

//MACHINE THAT ALLOCATES BIT_ALIGN_MACHINE TO EACH OF THE 16 DATA CHANNELS, ONE AT A TIME	
RESOURCE_SHARING_CONTROL RESOURCE_SHARING_CONTROL_0
	(
	.CHAN_SEL(CHAN_SEL),
	.ALL_CHANNELS_ALIGNED(TRAINING_DONE),
	.DATA_ALIGNED(DATA_ALIGNED),
	.START_ALIGN(START_ALIGN),
	.CLK(RXCLKDIV),
	.RST(RESET),
	.REPEAT_PROC(1'b0)
	);	

//MACHINE THAT ADJUSTS DELAY OF A SINGLE DATA CHANNEL TO OPTIMIZE SAMPLING POINT 
BIT_ALIGN_MACHINE BIT_ALIGN_MACHINE_0
	(
	.RXCLKDIV(RXCLKDIV),
	.RXDATA(DATA_TO_MACHINE),
	.RST(RESET||RESET_SM[15]),
	.USE_BITSLIP(1'b1),
	.SAP(START_ALIGN),
	.INC(INC_FROM_MACHINE),
	.ICE(ICE_FROM_MACHINE),
	.BITSLIP(BITSLIP_FROM_MACHINE),
	.DATA_ALIGNED(DATA_ALIGNED)
	);

//MACHINE THAT ALLOCATES RT_WINDOW_MONITOR TO EACH OF THE 16 DATA CHANNELS, ONE AT A TIME	
RESOURCE_SHARING_CONTROL RESOURCE_SHARING_CONTROL_1
	(
	.CHAN_SEL(CHAN_SEL_RT),
	.ALL_CHANNELS_ALIGNED(),
	.DATA_ALIGNED(DATA_ALIGNED_RT),
	.START_ALIGN(START_ALIGN_RT),
	.CLK(RXCLKDIV),
	.RST(RESET),
	.REPEAT_PROC(1'b1)
	);	

//MACHINE THAT ADJUSTS DATA CHANNEL DELAYS IN REAL-TIME TO ACCOUNT FOR VT VARIATION
RT_WINDOW_MONITOR RT_WINDOW_MONITOR_0
	(
	.CLOCK(RXCLKDIV),
	.RESET(RESET),
	.TRAINING_DONE(TRAINING_DONE & RT_MANUAL_DISABLE),
	.START(START_ALIGN_RT),
	.DATA_MASTER(DATA_TO_RT),
	.DATA_MONITOR(MONITOR_TO_RT),
	.INC_MONITOR(INC_MONITOR),
	.ICE_MONITOR(ICE_MONITOR),
	.INC_DATABUS(INC_DATABUS),
	.ICE_DATABUS(ICE_DATABUS),
	.DATA_ALIGNED_RT(DATA_ALIGNED_RT)
	); 	

//CHANNEL SELECT LOGIC TO SHARE RT_WINDOW_MONITOR IN ROUND ROBIN FASHION
always @(posedge RXCLKDIV) begin
case (CHAN_SEL_RT)
	4'b0000: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[5:0];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[5:0];
			INC_TO_ISERDES_RT <= {15'b000000000000000, INC_DATABUS};
			ICE_TO_ISERDES_RT <= {15'b000000000000000, ICE_DATABUS};
			INC_TO_MONITOR_RT <= {15'b000000000000000, INC_MONITOR};
			ICE_TO_MONITOR_RT <= {15'b000000000000000, ICE_MONITOR};
			end
	
	4'b0001: 	begin 
			DATA_TO_RT <= DATA_FROM_ISERDES[11:6];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[11:6];
			INC_TO_ISERDES_RT <= {14'b00000000000000, INC_DATABUS, 1'b0};
			ICE_TO_ISERDES_RT <= {14'b00000000000000, ICE_DATABUS, 1'b0};
			INC_TO_MONITOR_RT <= {14'b00000000000000, INC_MONITOR, 1'b0};
			ICE_TO_MONITOR_RT <= {14'b00000000000000, ICE_MONITOR, 1'b0};
			end
	
	4'b0010: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[17:12];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[17:12];
			INC_TO_ISERDES_RT <= {13'b0000000000000, INC_DATABUS, 2'b00};
			ICE_TO_ISERDES_RT <= {13'b0000000000000, ICE_DATABUS, 2'b00};
			INC_TO_MONITOR_RT <= {13'b0000000000000, INC_MONITOR, 2'b00};
			ICE_TO_MONITOR_RT <= {13'b0000000000000, ICE_MONITOR, 2'b00};
			end
	
	4'b0011: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[23:18];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[23:18];
			INC_TO_ISERDES_RT <= {12'b000000000000, INC_DATABUS, 3'b000};
			ICE_TO_ISERDES_RT <= {12'b000000000000, ICE_DATABUS, 3'b000};
			INC_TO_MONITOR_RT <= {12'b000000000000, INC_MONITOR, 3'b000};
			ICE_TO_MONITOR_RT <= {12'b000000000000, ICE_MONITOR, 3'b000};
			end
	
	4'b0100: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[29:24];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[29:24];
			INC_TO_ISERDES_RT <= {11'b00000000000, INC_DATABUS, 4'b0000};
			ICE_TO_ISERDES_RT <= {11'b00000000000, ICE_DATABUS, 4'b0000};
			INC_TO_MONITOR_RT <= {11'b00000000000, INC_MONITOR, 4'b0000};
			ICE_TO_MONITOR_RT <= {11'b00000000000, ICE_MONITOR, 4'b0000};
			end
	
	4'b0101: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[35:30];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[35:30];
			INC_TO_ISERDES_RT <= {10'b0000000000, INC_DATABUS, 5'b00000};
			ICE_TO_ISERDES_RT <= {10'b0000000000, ICE_DATABUS, 5'b00000};
			INC_TO_MONITOR_RT <= {10'b0000000000, INC_MONITOR, 5'b00000};
			ICE_TO_MONITOR_RT <= {10'b0000000000, ICE_MONITOR, 5'b00000};
			end
	
	4'b0110: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[41:36];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[41:36];
			INC_TO_ISERDES_RT <= {9'b000000000, INC_DATABUS, 6'b000000};
			ICE_TO_ISERDES_RT <= {9'b000000000, ICE_DATABUS, 6'b000000};
			INC_TO_MONITOR_RT <= {9'b000000000, INC_MONITOR, 6'b000000};
			ICE_TO_MONITOR_RT <= {9'b000000000, ICE_MONITOR, 6'b000000};
			end
	
	4'b0111: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[47:42];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[47:42];
			INC_TO_ISERDES_RT <= {8'b00000000, INC_DATABUS, 7'b0000000};
			ICE_TO_ISERDES_RT <= {8'b00000000, ICE_DATABUS, 7'b0000000};
			INC_TO_MONITOR_RT <= {8'b00000000, INC_MONITOR, 7'b0000000};
			ICE_TO_MONITOR_RT <= {8'b00000000, ICE_MONITOR, 7'b0000000};
			end
			
	4'b1000: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[53:48];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[53:48];
			INC_TO_ISERDES_RT <= {7'b0000000, INC_DATABUS, 8'b00000000};
			ICE_TO_ISERDES_RT <= {7'b0000000, ICE_DATABUS, 8'b00000000};
			INC_TO_MONITOR_RT <= {7'b0000000, INC_MONITOR, 8'b00000000};
			ICE_TO_MONITOR_RT <= {7'b0000000, ICE_MONITOR, 8'b00000000};
			end
			
	4'b1001: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[59:54];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[59:54];
			INC_TO_ISERDES_RT <= {6'b000000, INC_DATABUS, 9'b000000000};
			ICE_TO_ISERDES_RT <= {6'b000000, ICE_DATABUS, 9'b000000000};
			INC_TO_MONITOR_RT <= {6'b000000, INC_MONITOR, 9'b000000000};
			ICE_TO_MONITOR_RT <= {6'b000000, ICE_MONITOR, 9'b000000000};
			end
	
	4'b1010: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[65:60];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[65:60];
			INC_TO_ISERDES_RT <= {5'b00000, INC_DATABUS, 10'b0000000000};
			ICE_TO_ISERDES_RT <= {5'b00000, ICE_DATABUS, 10'b0000000000};
			INC_TO_MONITOR_RT <= {5'b00000, INC_MONITOR, 10'b0000000000};
			ICE_TO_MONITOR_RT <= {5'b00000, ICE_MONITOR, 10'b0000000000};
			end
	
	4'b1011: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[71:66];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[71:66];
			INC_TO_ISERDES_RT <= {4'b0000, INC_DATABUS, 11'b00000000000};
			ICE_TO_ISERDES_RT <= {4'b0000, ICE_DATABUS, 11'b00000000000};
			INC_TO_MONITOR_RT <= {4'b0000, INC_MONITOR, 11'b00000000000};
			ICE_TO_MONITOR_RT <= {4'b0000, ICE_MONITOR, 11'b00000000000};
			end
	
	4'b1100: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[77:72];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[77:72];
			INC_TO_ISERDES_RT <= {3'b000, INC_DATABUS, 12'b000000000000};
			ICE_TO_ISERDES_RT <= {3'b000, ICE_DATABUS, 12'b000000000000};
			INC_TO_MONITOR_RT <= {3'b000, INC_MONITOR, 12'b000000000000};
			ICE_TO_MONITOR_RT <= {3'b000, ICE_MONITOR, 12'b000000000000};
			end
	
	4'b1101: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[83:78];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[83:78];
			INC_TO_ISERDES_RT <= {2'b00, INC_DATABUS, 13'b0000000000000};
			ICE_TO_ISERDES_RT <= {2'b00, ICE_DATABUS, 13'b0000000000000};
			INC_TO_MONITOR_RT <= {2'b00, INC_MONITOR, 13'b0000000000000};
			ICE_TO_MONITOR_RT <= {2'b00, ICE_MONITOR, 13'b0000000000000};
			end
			
	4'b1110: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[89:84];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[89:84];
			INC_TO_ISERDES_RT <= {1'b0, INC_DATABUS, 14'b00000000000000};
			ICE_TO_ISERDES_RT <= {1'b0, ICE_DATABUS, 14'b00000000000000};
			INC_TO_MONITOR_RT <= {1'b0, INC_MONITOR, 14'b00000000000000};
			ICE_TO_MONITOR_RT <= {1'b0, ICE_MONITOR, 14'b00000000000000};
			end
			
	4'b1111: 	begin
			DATA_TO_RT <= DATA_FROM_ISERDES[95:90];
			MONITOR_TO_RT <= DATA_FROM_ISERDES_MON[95:90];
			INC_TO_ISERDES_RT <= {INC_DATABUS, 15'b000000000000000};
			ICE_TO_ISERDES_RT <= {ICE_DATABUS, 15'b000000000000000};
			INC_TO_MONITOR_RT <= {INC_MONITOR, 15'b000000000000000};
			ICE_TO_MONITOR_RT <= {ICE_MONITOR, 15'b000000000000000};
			end
endcase
end

 
//SHORTEN EACH EXTERNAL INC AND DEC PULSE TO ONE RXCLKDIV CYCLE
always @(posedge RXCLKDIV)
   begin						
      INC_CAPTURE[0] <= INC_PAD;			//ASYNCHRONOUS ENTRY POINT
      DEC_CAPTURE[0] <= DEC_PAD;
      BITSLIP_CAPTURE[0] <= BITSLIP_PAD;
      begin
         for(I = 0; I <= 3 - 1; I = I + 1)
         begin
            INC_CAPTURE[I + 1] <= INC_CAPTURE[I];	//METASTABLE FLIP-FLOPS
            DEC_CAPTURE[I + 1] <= DEC_CAPTURE[I];	
            BITSLIP_CAPTURE[I + 1] <= BITSLIP_CAPTURE[I];	
         end
      end
      INC_PULSE <= INC_CAPTURE[2] & ~INC_CAPTURE[3];	//STABLE, SINGLE PULSE
      DEC_PULSE <= DEC_CAPTURE[2] & ~DEC_CAPTURE[3];	
      BITSLIP_PULSE <= BITSLIP_CAPTURE[2] & ~BITSLIP_CAPTURE[3];
   end
   
//KEEP TRACK OF CURRENT TAP SETTING OF IDELAY IN DATA PATH OF CHANNELS 0-15
COUNT_TO_64 TAP_COUNTER_00(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[00]||ICE_TO_ISERDES_RT[00]), .ud(INC_DELAY||INC_TO_ISERDES[00]||INC_TO_ISERDES_RT[00]), .counter_value(TAP_00));
COUNT_TO_64 TAP_COUNTER_01(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[01]||ICE_TO_ISERDES_RT[01]), .ud(INC_DELAY||INC_TO_ISERDES[01]||INC_TO_ISERDES_RT[01]), .counter_value(TAP_01));
COUNT_TO_64 TAP_COUNTER_02(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[02]||ICE_TO_ISERDES_RT[02]), .ud(INC_DELAY||INC_TO_ISERDES[02]||INC_TO_ISERDES_RT[02]), .counter_value(TAP_02));
COUNT_TO_64 TAP_COUNTER_03(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[03]||ICE_TO_ISERDES_RT[03]), .ud(INC_DELAY||INC_TO_ISERDES[03]||INC_TO_ISERDES_RT[03]), .counter_value(TAP_03));
COUNT_TO_64 TAP_COUNTER_04(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[04]||ICE_TO_ISERDES_RT[04]), .ud(INC_DELAY||INC_TO_ISERDES[04]||INC_TO_ISERDES_RT[04]), .counter_value(TAP_04));
COUNT_TO_64 TAP_COUNTER_05(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[05]||ICE_TO_ISERDES_RT[05]), .ud(INC_DELAY||INC_TO_ISERDES[05]||INC_TO_ISERDES_RT[05]), .counter_value(TAP_05));
COUNT_TO_64 TAP_COUNTER_06(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[06]||ICE_TO_ISERDES_RT[06]), .ud(INC_DELAY||INC_TO_ISERDES[06]||INC_TO_ISERDES_RT[06]), .counter_value(TAP_06));
COUNT_TO_64 TAP_COUNTER_07(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[07]||ICE_TO_ISERDES_RT[07]), .ud(INC_DELAY||INC_TO_ISERDES[07]||INC_TO_ISERDES_RT[07]), .counter_value(TAP_07));
COUNT_TO_64 TAP_COUNTER_08(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[08]||ICE_TO_ISERDES_RT[08]), .ud(INC_DELAY||INC_TO_ISERDES[08]||INC_TO_ISERDES_RT[08]), .counter_value(TAP_08));
COUNT_TO_64 TAP_COUNTER_09(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[09]||ICE_TO_ISERDES_RT[09]), .ud(INC_DELAY||INC_TO_ISERDES[09]||INC_TO_ISERDES_RT[09]), .counter_value(TAP_09));
COUNT_TO_64 TAP_COUNTER_10(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[10]||ICE_TO_ISERDES_RT[10]), .ud(INC_DELAY||INC_TO_ISERDES[10]||INC_TO_ISERDES_RT[10]), .counter_value(TAP_10));
COUNT_TO_64 TAP_COUNTER_11(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[11]||ICE_TO_ISERDES_RT[11]), .ud(INC_DELAY||INC_TO_ISERDES[11]||INC_TO_ISERDES_RT[11]), .counter_value(TAP_11));
COUNT_TO_64 TAP_COUNTER_12(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[12]||ICE_TO_ISERDES_RT[12]), .ud(INC_DELAY||INC_TO_ISERDES[12]||INC_TO_ISERDES_RT[12]), .counter_value(TAP_12));
COUNT_TO_64 TAP_COUNTER_13(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[13]||ICE_TO_ISERDES_RT[13]), .ud(INC_DELAY||INC_TO_ISERDES[13]||INC_TO_ISERDES_RT[13]), .counter_value(TAP_13));
COUNT_TO_64 TAP_COUNTER_14(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[14]||ICE_TO_ISERDES_RT[14]), .ud(INC_DELAY||INC_TO_ISERDES[14]||INC_TO_ISERDES_RT[14]), .counter_value(TAP_14));
COUNT_TO_64 TAP_COUNTER_15(.clk(RXCLKDIV), .rst(IDLY_RESET||RESET), .count(ICE_DELAY||ICE_TO_ISERDES[15]||ICE_TO_ISERDES_RT[15]), .ud(INC_DELAY||INC_TO_ISERDES[15]||INC_TO_ISERDES_RT[15]), .counter_value(TAP_15));


//CIRCUIT TO PRODUCE RESET DELAYED BY 20 CYCLES FOR BIT_ALIGN_MACHINE
integer		K;
always @(posedge RXCLKDIV)
	begin
	RESET_SM[0] <= RESET;
        for(K = 0; K <= 20 - 1; K = K + 1)
         begin
            RESET_SM[K+1] <= RESET_SM[K];
         end
	end

//DATA INPUT BUFFERS WITH DUAL OUTPUTS (ONE INVERTED AND ONE NOT INVERTED)
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_00(.O(DATA_RX_BUF[00]), .OB(DATA_RX_BUF_MON[00]), .I(DATA_RX_P[00]), .IB(DATA_RX_N[00]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_01(.O(DATA_RX_BUF[01]), .OB(DATA_RX_BUF_MON[01]), .I(DATA_RX_P[01]), .IB(DATA_RX_N[01]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_02(.O(DATA_RX_BUF[02]), .OB(DATA_RX_BUF_MON[02]), .I(DATA_RX_P[02]), .IB(DATA_RX_N[02]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_03(.O(DATA_RX_BUF[03]), .OB(DATA_RX_BUF_MON[03]), .I(DATA_RX_P[03]), .IB(DATA_RX_N[03]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_04(.O(DATA_RX_BUF[04]), .OB(DATA_RX_BUF_MON[04]), .I(DATA_RX_P[04]), .IB(DATA_RX_N[04]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_05(.O(DATA_RX_BUF[05]), .OB(DATA_RX_BUF_MON[05]), .I(DATA_RX_P[05]), .IB(DATA_RX_N[05]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_06(.O(DATA_RX_BUF[06]), .OB(DATA_RX_BUF_MON[06]), .I(DATA_RX_P[06]), .IB(DATA_RX_N[06]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_07(.O(DATA_RX_BUF[07]), .OB(DATA_RX_BUF_MON[07]), .I(DATA_RX_P[07]), .IB(DATA_RX_N[07]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_08(.O(DATA_RX_BUF[08]), .OB(DATA_RX_BUF_MON[08]), .I(DATA_RX_P[08]), .IB(DATA_RX_N[08]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_09(.O(DATA_RX_BUF[09]), .OB(DATA_RX_BUF_MON[09]), .I(DATA_RX_P[09]), .IB(DATA_RX_N[09]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_10(.O(DATA_RX_BUF[10]), .OB(DATA_RX_BUF_MON[10]), .I(DATA_RX_P[10]), .IB(DATA_RX_N[10]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_11(.O(DATA_RX_BUF[11]), .OB(DATA_RX_BUF_MON[11]), .I(DATA_RX_P[11]), .IB(DATA_RX_N[11]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_12(.O(DATA_RX_BUF[12]), .OB(DATA_RX_BUF_MON[12]), .I(DATA_RX_P[12]), .IB(DATA_RX_N[12]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_13(.O(DATA_RX_BUF[13]), .OB(DATA_RX_BUF_MON[13]), .I(DATA_RX_P[13]), .IB(DATA_RX_N[13]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_14(.O(DATA_RX_BUF[14]), .OB(DATA_RX_BUF_MON[14]), .I(DATA_RX_P[14]), .IB(DATA_RX_N[14]));
IBUFDS_DIFF_OUT #(.IOSTANDARD("LVDS_25")) RX_DATA_IN_15(.O(DATA_RX_BUF[15]), .OB(DATA_RX_BUF_MON[15]), .I(DATA_RX_P[15]), .IB(DATA_RX_N[15]));

//synthesis attribute DIFF_TERM of RX_DATA_IN_00 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_01 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_02 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_03 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_04 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_05 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_06 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_07 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_08 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_09 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_10 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_11 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_12 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_13 is TRUE
//synthesis attribute DIFF_TERM of RX_DATA_IN_14 is TRUE                                              
//synthesis attribute DIFF_TERM of RX_DATA_IN_15 is TRUE                                              

//MASTER SIDE IODELAYS
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_00 (.DATAOUT(DATA_RX_IDLY[00]), .IDATAIN(DATA_RX_BUF[00]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[00]||ICE_TO_ISERDES_RT[00]), .INC(INC_DELAY||INC_TO_ISERDES[00]||INC_TO_ISERDES_RT[00]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_01 (.DATAOUT(DATA_RX_IDLY[01]), .IDATAIN(DATA_RX_BUF[01]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[01]||ICE_TO_ISERDES_RT[01]), .INC(INC_DELAY||INC_TO_ISERDES[01]||INC_TO_ISERDES_RT[01]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_02 (.DATAOUT(DATA_RX_IDLY[02]), .IDATAIN(DATA_RX_BUF[02]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[02]||ICE_TO_ISERDES_RT[02]), .INC(INC_DELAY||INC_TO_ISERDES[02]||INC_TO_ISERDES_RT[02]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_03 (.DATAOUT(DATA_RX_IDLY[03]), .IDATAIN(DATA_RX_BUF[03]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[03]||ICE_TO_ISERDES_RT[03]), .INC(INC_DELAY||INC_TO_ISERDES[03]||INC_TO_ISERDES_RT[03]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_04 (.DATAOUT(DATA_RX_IDLY[04]), .IDATAIN(DATA_RX_BUF[04]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[04]||ICE_TO_ISERDES_RT[04]), .INC(INC_DELAY||INC_TO_ISERDES[04]||INC_TO_ISERDES_RT[04]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_05 (.DATAOUT(DATA_RX_IDLY[05]), .IDATAIN(DATA_RX_BUF[05]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[05]||ICE_TO_ISERDES_RT[05]), .INC(INC_DELAY||INC_TO_ISERDES[05]||INC_TO_ISERDES_RT[05]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_06 (.DATAOUT(DATA_RX_IDLY[06]), .IDATAIN(DATA_RX_BUF[06]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[06]||ICE_TO_ISERDES_RT[06]), .INC(INC_DELAY||INC_TO_ISERDES[06]||INC_TO_ISERDES_RT[06]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_07 (.DATAOUT(DATA_RX_IDLY[07]), .IDATAIN(DATA_RX_BUF[07]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[07]||ICE_TO_ISERDES_RT[07]), .INC(INC_DELAY||INC_TO_ISERDES[07]||INC_TO_ISERDES_RT[07]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_08 (.DATAOUT(DATA_RX_IDLY[08]), .IDATAIN(DATA_RX_BUF[08]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[08]||ICE_TO_ISERDES_RT[08]), .INC(INC_DELAY||INC_TO_ISERDES[08]||INC_TO_ISERDES_RT[08]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_09 (.DATAOUT(DATA_RX_IDLY[09]), .IDATAIN(DATA_RX_BUF[09]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[09]||ICE_TO_ISERDES_RT[09]), .INC(INC_DELAY||INC_TO_ISERDES[09]||INC_TO_ISERDES_RT[09]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_10 (.DATAOUT(DATA_RX_IDLY[10]), .IDATAIN(DATA_RX_BUF[10]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[10]||ICE_TO_ISERDES_RT[10]), .INC(INC_DELAY||INC_TO_ISERDES[10]||INC_TO_ISERDES_RT[10]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_11 (.DATAOUT(DATA_RX_IDLY[11]), .IDATAIN(DATA_RX_BUF[11]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[11]||ICE_TO_ISERDES_RT[11]), .INC(INC_DELAY||INC_TO_ISERDES[11]||INC_TO_ISERDES_RT[11]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_12 (.DATAOUT(DATA_RX_IDLY[12]), .IDATAIN(DATA_RX_BUF[12]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[12]||ICE_TO_ISERDES_RT[12]), .INC(INC_DELAY||INC_TO_ISERDES[12]||INC_TO_ISERDES_RT[12]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_13 (.DATAOUT(DATA_RX_IDLY[13]), .IDATAIN(DATA_RX_BUF[13]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[13]||ICE_TO_ISERDES_RT[13]), .INC(INC_DELAY||INC_TO_ISERDES[13]||INC_TO_ISERDES_RT[13]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_14 (.DATAOUT(DATA_RX_IDLY[14]), .IDATAIN(DATA_RX_BUF[14]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[14]||ICE_TO_ISERDES_RT[14]), .INC(INC_DELAY||INC_TO_ISERDES[14]||INC_TO_ISERDES_RT[14]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_DATA_15 (.DATAOUT(DATA_RX_IDLY[15]), .IDATAIN(DATA_RX_BUF[15]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[15]||ICE_TO_ISERDES_RT[15]), .INC(INC_DELAY||INC_TO_ISERDES[15]||INC_TO_ISERDES_RT[15]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));                                                                                                                                                                                                                                                                                          
                                                                                                   

//MASTER SIDE ISERDES                                                                                                    
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_00(.Q1(DATA_FROM_ISERDES[005]), .Q2(DATA_FROM_ISERDES[004]), .Q3(DATA_FROM_ISERDES[003]), .Q4(DATA_FROM_ISERDES[002]), .Q5(DATA_FROM_ISERDES[001]), .Q6(DATA_FROM_ISERDES[000]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[00]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[00]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_01(.Q1(DATA_FROM_ISERDES[011]), .Q2(DATA_FROM_ISERDES[010]), .Q3(DATA_FROM_ISERDES[009]), .Q4(DATA_FROM_ISERDES[008]), .Q5(DATA_FROM_ISERDES[007]), .Q6(DATA_FROM_ISERDES[006]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[01]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[01]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_02(.Q1(DATA_FROM_ISERDES[017]), .Q2(DATA_FROM_ISERDES[016]), .Q3(DATA_FROM_ISERDES[015]), .Q4(DATA_FROM_ISERDES[014]), .Q5(DATA_FROM_ISERDES[013]), .Q6(DATA_FROM_ISERDES[012]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[02]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[02]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_03(.Q1(DATA_FROM_ISERDES[023]), .Q2(DATA_FROM_ISERDES[022]), .Q3(DATA_FROM_ISERDES[021]), .Q4(DATA_FROM_ISERDES[020]), .Q5(DATA_FROM_ISERDES[019]), .Q6(DATA_FROM_ISERDES[018]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[03]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[03]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_04(.Q1(DATA_FROM_ISERDES[029]), .Q2(DATA_FROM_ISERDES[028]), .Q3(DATA_FROM_ISERDES[027]), .Q4(DATA_FROM_ISERDES[026]), .Q5(DATA_FROM_ISERDES[025]), .Q6(DATA_FROM_ISERDES[024]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[04]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[04]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_05(.Q1(DATA_FROM_ISERDES[035]), .Q2(DATA_FROM_ISERDES[034]), .Q3(DATA_FROM_ISERDES[033]), .Q4(DATA_FROM_ISERDES[032]), .Q5(DATA_FROM_ISERDES[031]), .Q6(DATA_FROM_ISERDES[030]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[05]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[05]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_06(.Q1(DATA_FROM_ISERDES[041]), .Q2(DATA_FROM_ISERDES[040]), .Q3(DATA_FROM_ISERDES[039]), .Q4(DATA_FROM_ISERDES[038]), .Q5(DATA_FROM_ISERDES[037]), .Q6(DATA_FROM_ISERDES[036]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[06]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[06]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_07(.Q1(DATA_FROM_ISERDES[047]), .Q2(DATA_FROM_ISERDES[046]), .Q3(DATA_FROM_ISERDES[045]), .Q4(DATA_FROM_ISERDES[044]), .Q5(DATA_FROM_ISERDES[043]), .Q6(DATA_FROM_ISERDES[042]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[07]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[07]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_08(.Q1(DATA_FROM_ISERDES[053]), .Q2(DATA_FROM_ISERDES[052]), .Q3(DATA_FROM_ISERDES[051]), .Q4(DATA_FROM_ISERDES[050]), .Q5(DATA_FROM_ISERDES[049]), .Q6(DATA_FROM_ISERDES[048]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[08]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[08]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_09(.Q1(DATA_FROM_ISERDES[059]), .Q2(DATA_FROM_ISERDES[058]), .Q3(DATA_FROM_ISERDES[057]), .Q4(DATA_FROM_ISERDES[056]), .Q5(DATA_FROM_ISERDES[055]), .Q6(DATA_FROM_ISERDES[054]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[09]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[09]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_10(.Q1(DATA_FROM_ISERDES[065]), .Q2(DATA_FROM_ISERDES[064]), .Q3(DATA_FROM_ISERDES[063]), .Q4(DATA_FROM_ISERDES[062]), .Q5(DATA_FROM_ISERDES[061]), .Q6(DATA_FROM_ISERDES[060]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[10]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[10]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_11(.Q1(DATA_FROM_ISERDES[071]), .Q2(DATA_FROM_ISERDES[070]), .Q3(DATA_FROM_ISERDES[069]), .Q4(DATA_FROM_ISERDES[068]), .Q5(DATA_FROM_ISERDES[067]), .Q6(DATA_FROM_ISERDES[066]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[11]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[11]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_12(.Q1(DATA_FROM_ISERDES[077]), .Q2(DATA_FROM_ISERDES[076]), .Q3(DATA_FROM_ISERDES[075]), .Q4(DATA_FROM_ISERDES[074]), .Q5(DATA_FROM_ISERDES[073]), .Q6(DATA_FROM_ISERDES[072]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[12]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[12]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_13(.Q1(DATA_FROM_ISERDES[083]), .Q2(DATA_FROM_ISERDES[082]), .Q3(DATA_FROM_ISERDES[081]), .Q4(DATA_FROM_ISERDES[080]), .Q5(DATA_FROM_ISERDES[079]), .Q6(DATA_FROM_ISERDES[078]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[13]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[13]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_14(.Q1(DATA_FROM_ISERDES[089]), .Q2(DATA_FROM_ISERDES[088]), .Q3(DATA_FROM_ISERDES[087]), .Q4(DATA_FROM_ISERDES[086]), .Q5(DATA_FROM_ISERDES[085]), .Q6(DATA_FROM_ISERDES[084]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[14]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[14]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_DATA_15(.Q1(DATA_FROM_ISERDES[095]), .Q2(DATA_FROM_ISERDES[094]), .Q3(DATA_FROM_ISERDES[093]), .Q4(DATA_FROM_ISERDES[092]), .Q5(DATA_FROM_ISERDES[091]), .Q6(DATA_FROM_ISERDES[090]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[15]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY[15]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));	


//MONITOR SIDE IODELAYS
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_00 (.DATAOUT(DATA_RX_IDLY_MON[00]), .IDATAIN(DATA_RX_BUF_MON[00]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[00]||ICE_TO_MONITOR_RT[00]), .INC(INC_DELAY||INC_TO_ISERDES[00]||INC_TO_MONITOR_RT[00]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_01 (.DATAOUT(DATA_RX_IDLY_MON[01]), .IDATAIN(DATA_RX_BUF_MON[01]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[01]||ICE_TO_MONITOR_RT[01]), .INC(INC_DELAY||INC_TO_ISERDES[01]||INC_TO_MONITOR_RT[01]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_02 (.DATAOUT(DATA_RX_IDLY_MON[02]), .IDATAIN(DATA_RX_BUF_MON[02]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[02]||ICE_TO_MONITOR_RT[02]), .INC(INC_DELAY||INC_TO_ISERDES[02]||INC_TO_MONITOR_RT[02]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_03 (.DATAOUT(DATA_RX_IDLY_MON[03]), .IDATAIN(DATA_RX_BUF_MON[03]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[03]||ICE_TO_MONITOR_RT[03]), .INC(INC_DELAY||INC_TO_ISERDES[03]||INC_TO_MONITOR_RT[03]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_04 (.DATAOUT(DATA_RX_IDLY_MON[04]), .IDATAIN(DATA_RX_BUF_MON[04]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[04]||ICE_TO_MONITOR_RT[04]), .INC(INC_DELAY||INC_TO_ISERDES[04]||INC_TO_MONITOR_RT[04]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_05 (.DATAOUT(DATA_RX_IDLY_MON[05]), .IDATAIN(DATA_RX_BUF_MON[05]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[05]||ICE_TO_MONITOR_RT[05]), .INC(INC_DELAY||INC_TO_ISERDES[05]||INC_TO_MONITOR_RT[05]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_06 (.DATAOUT(DATA_RX_IDLY_MON[06]), .IDATAIN(DATA_RX_BUF_MON[06]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[06]||ICE_TO_MONITOR_RT[06]), .INC(INC_DELAY||INC_TO_ISERDES[06]||INC_TO_MONITOR_RT[06]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_07 (.DATAOUT(DATA_RX_IDLY_MON[07]), .IDATAIN(DATA_RX_BUF_MON[07]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[07]||ICE_TO_MONITOR_RT[07]), .INC(INC_DELAY||INC_TO_ISERDES[07]||INC_TO_MONITOR_RT[07]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_08 (.DATAOUT(DATA_RX_IDLY_MON[08]), .IDATAIN(DATA_RX_BUF_MON[08]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[08]||ICE_TO_MONITOR_RT[08]), .INC(INC_DELAY||INC_TO_ISERDES[08]||INC_TO_MONITOR_RT[08]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_09 (.DATAOUT(DATA_RX_IDLY_MON[09]), .IDATAIN(DATA_RX_BUF_MON[09]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[09]||ICE_TO_MONITOR_RT[09]), .INC(INC_DELAY||INC_TO_ISERDES[09]||INC_TO_MONITOR_RT[09]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_10 (.DATAOUT(DATA_RX_IDLY_MON[10]), .IDATAIN(DATA_RX_BUF_MON[10]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[10]||ICE_TO_MONITOR_RT[10]), .INC(INC_DELAY||INC_TO_ISERDES[10]||INC_TO_MONITOR_RT[10]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_11 (.DATAOUT(DATA_RX_IDLY_MON[11]), .IDATAIN(DATA_RX_BUF_MON[11]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[11]||ICE_TO_MONITOR_RT[11]), .INC(INC_DELAY||INC_TO_ISERDES[11]||INC_TO_MONITOR_RT[11]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_12 (.DATAOUT(DATA_RX_IDLY_MON[12]), .IDATAIN(DATA_RX_BUF_MON[12]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[12]||ICE_TO_MONITOR_RT[12]), .INC(INC_DELAY||INC_TO_ISERDES[12]||INC_TO_MONITOR_RT[12]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_13 (.DATAOUT(DATA_RX_IDLY_MON[13]), .IDATAIN(DATA_RX_BUF_MON[13]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[13]||ICE_TO_MONITOR_RT[13]), .INC(INC_DELAY||INC_TO_ISERDES[13]||INC_TO_MONITOR_RT[13]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_14 (.DATAOUT(DATA_RX_IDLY_MON[14]), .IDATAIN(DATA_RX_BUF_MON[14]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[14]||ICE_TO_MONITOR_RT[14]), .INC(INC_DELAY||INC_TO_ISERDES[14]||INC_TO_MONITOR_RT[14]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));
IODELAY #(.IDELAY_TYPE("VARIABLE"), .IDELAY_VALUE(0), .ODELAY_VALUE(0), .REFCLK_FREQUENCY(200.00), .HIGH_PERFORMANCE_MODE("TRUE")) IODELAY_RX_MON_15 (.DATAOUT(DATA_RX_IDLY_MON[15]), .IDATAIN(DATA_RX_BUF_MON[15]), .ODATAIN(1'b0), .DATAIN(1'b0), .T(), .CE(ICE_DELAY||ICE_TO_ISERDES[15]||ICE_TO_MONITOR_RT[15]), .INC(INC_DELAY||INC_TO_ISERDES[15]||INC_TO_MONITOR_RT[15]), .C(RXCLKDIV), .RST(IDLY_RESET||RESET));

                                                                                                   
//MONITOR SIDE ISERDES                                                                                                    
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_00(.Q1(DATA_FROM_ISERDES_MON[005]), .Q2(DATA_FROM_ISERDES_MON[004]), .Q3(DATA_FROM_ISERDES_MON[003]), .Q4(DATA_FROM_ISERDES_MON[002]), .Q5(DATA_FROM_ISERDES_MON[001]), .Q6(DATA_FROM_ISERDES_MON[000]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[00]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[00]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_01(.Q1(DATA_FROM_ISERDES_MON[011]), .Q2(DATA_FROM_ISERDES_MON[010]), .Q3(DATA_FROM_ISERDES_MON[009]), .Q4(DATA_FROM_ISERDES_MON[008]), .Q5(DATA_FROM_ISERDES_MON[007]), .Q6(DATA_FROM_ISERDES_MON[006]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[01]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[01]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_02(.Q1(DATA_FROM_ISERDES_MON[017]), .Q2(DATA_FROM_ISERDES_MON[016]), .Q3(DATA_FROM_ISERDES_MON[015]), .Q4(DATA_FROM_ISERDES_MON[014]), .Q5(DATA_FROM_ISERDES_MON[013]), .Q6(DATA_FROM_ISERDES_MON[012]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[02]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[02]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_03(.Q1(DATA_FROM_ISERDES_MON[023]), .Q2(DATA_FROM_ISERDES_MON[022]), .Q3(DATA_FROM_ISERDES_MON[021]), .Q4(DATA_FROM_ISERDES_MON[020]), .Q5(DATA_FROM_ISERDES_MON[019]), .Q6(DATA_FROM_ISERDES_MON[018]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[03]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[03]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_04(.Q1(DATA_FROM_ISERDES_MON[029]), .Q2(DATA_FROM_ISERDES_MON[028]), .Q3(DATA_FROM_ISERDES_MON[027]), .Q4(DATA_FROM_ISERDES_MON[026]), .Q5(DATA_FROM_ISERDES_MON[025]), .Q6(DATA_FROM_ISERDES_MON[024]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[04]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[04]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_05(.Q1(DATA_FROM_ISERDES_MON[035]), .Q2(DATA_FROM_ISERDES_MON[034]), .Q3(DATA_FROM_ISERDES_MON[033]), .Q4(DATA_FROM_ISERDES_MON[032]), .Q5(DATA_FROM_ISERDES_MON[031]), .Q6(DATA_FROM_ISERDES_MON[030]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[05]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[05]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_06(.Q1(DATA_FROM_ISERDES_MON[041]), .Q2(DATA_FROM_ISERDES_MON[040]), .Q3(DATA_FROM_ISERDES_MON[039]), .Q4(DATA_FROM_ISERDES_MON[038]), .Q5(DATA_FROM_ISERDES_MON[037]), .Q6(DATA_FROM_ISERDES_MON[036]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[06]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[06]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_07(.Q1(DATA_FROM_ISERDES_MON[047]), .Q2(DATA_FROM_ISERDES_MON[046]), .Q3(DATA_FROM_ISERDES_MON[045]), .Q4(DATA_FROM_ISERDES_MON[044]), .Q5(DATA_FROM_ISERDES_MON[043]), .Q6(DATA_FROM_ISERDES_MON[042]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[07]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[07]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_08(.Q1(DATA_FROM_ISERDES_MON[053]), .Q2(DATA_FROM_ISERDES_MON[052]), .Q3(DATA_FROM_ISERDES_MON[051]), .Q4(DATA_FROM_ISERDES_MON[050]), .Q5(DATA_FROM_ISERDES_MON[049]), .Q6(DATA_FROM_ISERDES_MON[048]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[08]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[08]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_09(.Q1(DATA_FROM_ISERDES_MON[059]), .Q2(DATA_FROM_ISERDES_MON[058]), .Q3(DATA_FROM_ISERDES_MON[057]), .Q4(DATA_FROM_ISERDES_MON[056]), .Q5(DATA_FROM_ISERDES_MON[055]), .Q6(DATA_FROM_ISERDES_MON[054]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[09]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[09]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_10(.Q1(DATA_FROM_ISERDES_MON[065]), .Q2(DATA_FROM_ISERDES_MON[064]), .Q3(DATA_FROM_ISERDES_MON[063]), .Q4(DATA_FROM_ISERDES_MON[062]), .Q5(DATA_FROM_ISERDES_MON[061]), .Q6(DATA_FROM_ISERDES_MON[060]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[10]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[10]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_11(.Q1(DATA_FROM_ISERDES_MON[071]), .Q2(DATA_FROM_ISERDES_MON[070]), .Q3(DATA_FROM_ISERDES_MON[069]), .Q4(DATA_FROM_ISERDES_MON[068]), .Q5(DATA_FROM_ISERDES_MON[067]), .Q6(DATA_FROM_ISERDES_MON[066]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[11]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[11]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_12(.Q1(DATA_FROM_ISERDES_MON[077]), .Q2(DATA_FROM_ISERDES_MON[076]), .Q3(DATA_FROM_ISERDES_MON[075]), .Q4(DATA_FROM_ISERDES_MON[074]), .Q5(DATA_FROM_ISERDES_MON[073]), .Q6(DATA_FROM_ISERDES_MON[072]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[12]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[12]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_13(.Q1(DATA_FROM_ISERDES_MON[083]), .Q2(DATA_FROM_ISERDES_MON[082]), .Q3(DATA_FROM_ISERDES_MON[081]), .Q4(DATA_FROM_ISERDES_MON[080]), .Q5(DATA_FROM_ISERDES_MON[079]), .Q6(DATA_FROM_ISERDES_MON[078]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[13]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[13]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_14(.Q1(DATA_FROM_ISERDES_MON[089]), .Q2(DATA_FROM_ISERDES_MON[088]), .Q3(DATA_FROM_ISERDES_MON[087]), .Q4(DATA_FROM_ISERDES_MON[086]), .Q5(DATA_FROM_ISERDES_MON[085]), .Q6(DATA_FROM_ISERDES_MON[084]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[14]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[14]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));
ISERDES_NODELAY #(.BITSLIP_ENABLE("TRUE"), .DATA_RATE("DDR"), .DATA_WIDTH(6), .INIT_Q1(1'b0), .INIT_Q2(1'b0), .INIT_Q3(1'b0), .INIT_Q4(1'b0), .INTERFACE_TYPE("NETWORKING"), .NUM_CE(1), .SERDES_MODE("MASTER")) ISERDES_RX_MON_15(.Q1(DATA_FROM_ISERDES_MON[095]), .Q2(DATA_FROM_ISERDES_MON[094]), .Q3(DATA_FROM_ISERDES_MON[093]), .Q4(DATA_FROM_ISERDES_MON[092]), .Q5(DATA_FROM_ISERDES_MON[091]), .Q6(DATA_FROM_ISERDES_MON[090]), .SHIFTOUT1(), .SHIFTOUT2(), .BITSLIP(BITSLIP_PULSE||BITSLIP_TO_ISERDES[15]), .CE1(1'b1), .CE2(), .CLK(RXCLK), .CLKB(~RXCLK), .CLKDIV(RXCLKDIV), .D(DATA_RX_IDLY_MON[15]), .OCLK(), .SHIFTIN1(), .SHIFTIN2(), .RST(RESET));	

                 
endmodule 


module COUNT_TO_64(clk, rst, count, ud, counter_value);

//This module counts up/down between 0 to 63

input clk, rst, count, ud;
output [5:0] counter_value;

wire [5:0] counter_value_preserver;
reg [5:0] counter_value/*synthesis syn_noprune = 1*/;

always@(posedge clk or posedge rst)
begin
if(rst == 1'b1)
 counter_value = 6'h00;
else
 begin
  case({count,ud})
   2'b00: counter_value = counter_value_preserver;
   2'b01: counter_value = counter_value_preserver;
   2'b10: counter_value = counter_value_preserver - 1;
   2'b11: counter_value = counter_value_preserver + 1;
   default: counter_value = 6'h00;
  endcase
 end
end

assign counter_value_preserver = counter_value;

endmodule
