--/////////////////////////////////////////////////////////////////////////////
--
--    File Name:  DDR_6TO1_16CHAN_RT_RX.vhd
--      Version:  1.0
--         Date:  08/07/06
--        Model:  XAPP860 LVDS Receiver Module
--
--      Company:  Xilinx, Inc.
--  Contributor:  APD Applications Group
--
--   Disclaimer:  XILINX IS PROVIDING THIS DESIGN, CODE, OR
--                INFORMATION "AS IS" SOLELY FOR USE IN DEVELOPING
--                PROGRAMS AND SOLUTIONS FOR XILINX DEVICES.  BY
--                PROVIDING THIS DESIGN, CODE, OR INFORMATION AS
--                ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE,
--                APPLICATION OR STANDARD, XILINX IS MAKING NO
--                REPRESENTATION THAT THIS IMPLEMENTATION IS FREE
--                FROM ANY CLAIMS OF INFRINGEMENT, AND YOU ARE
--                RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY
--                REQUIRE FOR YOUR IMPLEMENTATION.  XILINX
--                EXPRESSLY DISCLAIMS ANY WARRANTY WHATSOEVER WITH
--                RESPECT TO THE ADEQUACY OF THE IMPLEMENTATION,
--                INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
--                REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE
--                FROM CLAIMS OF INFRINGEMENT, IMPLIED WARRANTIES
--                OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
--                PURPOSE.
--
--                (c) Copyright 2006 Xilinx, Inc.
--                All rights reserved.
--
--/////////////////////////////////////////////////////////////////////////////
-- 
-- Summary:
--
-- The DDR_6TO1_16CHAN_RT_RX module contains all logic in the XAPP860 LVDS Receiver,
-- including 16 channels of LVDS data, one channel of LVDS clock, an initial clock/data 
-- alignment algorithm, a real-time clock/data alignment algorithm, a control circuit to share the alignment machines among
-- all 16 data channels, and tap counters that keep track of the IDELAY tap
-- setting of all data channels.
--  
------------------------------------------------------------------

----
--
-- Library declarations
--
-- Standard IEEE libraries
--
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;
library unisim;
use unisim.vcomponents.all;
--

ENTITY DDR_6TO1_16CHAN_RT_RX IS
   PORT (
      DATA_RX_P   : IN std_logic_vector(15 DOWNTO 0); -- SERIAL SIDE RX DATA (P)
      DATA_RX_N   : IN std_logic_vector(15 DOWNTO 0); -- SERIAL SIDE RX DATA (N)
      CLOCK_RX_P  : IN std_logic;   -- FORWARDED CLOCK FROM TX (P)
      CLOCK_RX_N  : IN std_logic;   -- FORWARDED CLOCK FROM TX (N)
      INC_PAD     : IN std_logic;   -- MANUAL INCREMENT TO DATA DELAY
      DEC_PAD     : IN std_logic;   -- MANUAL DECREMENT TO DATA DELAY
      DATA_FROM_ISERDES       : OUT std_logic_vector(95 DOWNTO 0);   
                                 -- PARALLEL SIDE RX DATA
      RESET           : IN std_logic;   -- RX DOMAIN RESET
      IDLY_RESET        : IN std_logic;   -- IDELAY TAP RESET
      IDELAYCTRL_RESET  : IN std_logic;   -- IDELAYCTRL CIRCUIT RESET
      BITSLIP_PAD       : IN std_logic;   -- MANUAL BITSLIP TO DATA
      CLK200            : IN std_logic; -- 200 MHZ REFERENCE CLOCK TO IDELAYCTRL				
      TAP_00     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_01     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_02     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_03     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_04     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_05     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_06     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_07     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_08     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_09     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_10     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_11     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_12     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_13     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_14     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_15     : OUT std_logic_vector(5 DOWNTO 0); -- IDELAY TAP COUNT (0-63)
      TAP_CLK    : OUT std_logic_vector(5 DOWNTO 0); 
                            -- IDELAY TAP COUNT ON CLK CHANNEL (0-63)
      TRAINING_DONE  : OUT std_logic;   -- ALIGNMENT OF ALL CHANNELS COMPLETE
      RXCLK          : OUT std_logic;   
                                 -- FORWARDED CLOCK FROM TX (BUFIO OUTPUT)
      RXCLKDIV       : OUT std_logic;   
                                 -- PARALLEL SIDE RX CLOCK (DIVIDED FROM RXCLK)
      IDELAY_READY   : OUT std_logic;   
                                 -- FLAG INDICATING THAT IDELAYCTRL IS LOCKED
      RT_MANUAL_DISABLE       : IN std_logic);   
                                 -- DISABLE REAL TIME WINDOW MONITORING
END DDR_6TO1_16CHAN_RT_RX;

ARCHITECTURE translated OF DDR_6TO1_16CHAN_RT_RX IS

   COMPONENT COUNT_TO_64
      PORT (
         clk                     : IN  std_logic;
         rst                     : IN  std_logic;
         count                   : IN  std_logic;
         ud                      : IN  std_logic;
         counter_value           : OUT std_logic_vector(5 DOWNTO 0));
   END COMPONENT;

   COMPONENT BIT_ALIGN_MACHINE
      PORT (
         RXCLKDIV                : IN  std_logic;
         RXDATA                  : IN  std_logic_vector(5 DOWNTO 0);
         RST                     : IN  std_logic;
         USE_BITSLIP             : IN  std_logic;
         SAP                     : IN  std_logic;
         INC                     : OUT std_logic;
         ICE                     : OUT std_logic;
         BITSLIP                 : OUT std_logic;
         DATA_ALIGNED            : OUT std_logic);
   END COMPONENT;

   COMPONENT RESOURCE_SHARING_CONTROL
      PORT (
         CHAN_SEL                : OUT std_logic_vector(3 DOWNTO 0);
         ALL_CHANNELS_ALIGNED    : OUT std_logic;
         DATA_ALIGNED            : IN  std_logic;
         START_ALIGN             : OUT std_logic;
         CLK                     : IN  std_logic;
         RST                     : IN  std_logic;
         REPEAT_PROC             : IN  std_logic);
   END COMPONENT;

   COMPONENT RT_WINDOW_MONITOR
      PORT (
         CLOCK                   : IN  std_logic;
         RESET                   : IN  std_logic;
         TRAINING_DONE           : IN  std_logic;
         START                   : IN  std_logic;
         DATA_MASTER             : IN  std_logic_vector(5 DOWNTO 0);
         DATA_MONITOR            : IN  std_logic_vector(5 DOWNTO 0);
         INC_MONITOR             : OUT std_logic;
         ICE_MONITOR             : OUT std_logic;
         INC_DATABUS             : OUT std_logic;
         ICE_DATABUS             : OUT std_logic;
         DATA_ALIGNED_RT         : OUT std_logic);
   END COMPONENT;


  component IODELAY 
  generic(
      IDELAY_TYPE	: string	:= "DEFAULT";
      IDELAY_VALUE	: integer	:= 0;
      ODELAY_VALUE	: integer	:= 0;
      REFCLK_FREQUENCY	: real		:= 200.0;
      HIGH_PERFORMANCE_MODE	: string		:= "TRUE"
      );
  port(
      DATAOUT	: out std_logic;

      C		: in  std_logic;
      CE	: in  std_logic;
      DATAIN	: in  std_logic;
      IDATAIN	: in  std_logic;
      INC	: in  std_logic;
      ODATAIN	: in  std_logic;
      RST	: in  std_logic;
      T		: in  std_logic
      );
end component;


    component ISERDES_NODELAY 
   generic(
      BITSLIP_ENABLE	: boolean	:= false;
      DATA_RATE		: string	:= "DDR";
      DATA_WIDTH	: integer	:= 4;
      INIT_Q1		: std_logic		:= '0';
      INIT_Q2		: std_logic		:= '0';
      INIT_Q3		: std_logic		:= '0';
      INIT_Q4		: std_logic		:= '0';
      INTERFACE_TYPE	: string	:= "MEMORY";
      NUM_CE		: integer	:= 2;
      SERDES_MODE	: string	:= "MASTER"
      );
  port(
      Q1		: out std_logic;
      Q2		: out std_logic;
      Q3		: out std_logic;
      Q4		: out std_logic;
      Q5		: out std_logic;
      Q6		: out std_logic;
      SHIFTOUT1		: out std_logic;
      SHIFTOUT2		: out std_logic;
      BITSLIP		: in std_logic;
      CE1		: in std_logic;
      CE2		: in std_logic;
      CLK		: in std_logic;
      CLKDIV		: in std_logic;
      CLKB		: in std_logic;
      D			: in std_logic;
      OCLK		: in std_logic;
      RST		: in std_logic;
      SHIFTIN1		: in std_logic;
      SHIFTIN2		: in std_logic
    );
   end component;
 


   SIGNAL CLOCK_RX_BUF             :  std_logic;   
   SIGNAL DATA_RX_BUF              :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL DATA_RX_BUF_MON          :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL DATA_RX_IDLY             :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL DATA_RX_IDLY_MON         :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL DATA_FROM_ISERDES_MON    :  std_logic_vector(95 DOWNTO 0);   
   SIGNAL DATA_FROM_ISERDES_TEMP   :  std_logic_vector(95 DOWNTO 0);   
   SIGNAL CLOCK_RX_ISERDES_OUT     :  std_logic;   
   SIGNAL BITSLIP_FROM_MACHINE     :  std_logic;   
   SIGNAL ICE_FROM_MACHINE         :  std_logic;   
   SIGNAL INC_FROM_MACHINE         :  std_logic;   
   SIGNAL DATA_ALIGNED             :  std_logic;   
   SIGNAL DATA_ALIGNED_RT          :  std_logic;   
   SIGNAL SHIFT1                   :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL SHIFT2                   :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL CHAN_SEL                 :  std_logic_vector(3 DOWNTO 0);   
   SIGNAL CHAN_SEL_RT              :  std_logic_vector(3 DOWNTO 0);   
   SIGNAL INC_MONITOR              :  std_logic;   
   SIGNAL ICE_MONITOR              :  std_logic;   
   SIGNAL INC_DATABUS              :  std_logic;   
   SIGNAL ICE_DATABUS              :  std_logic;   
   SIGNAL INC_CAPTURE              :  std_logic_vector(3 DOWNTO 0);   
   SIGNAL DEC_CAPTURE              :  std_logic_vector(3 DOWNTO 0);   
   SIGNAL BITSLIP_CAPTURE          :  std_logic_vector(3 DOWNTO 0);   
   SIGNAL INC_PULSE                :  std_logic;   
   SIGNAL DEC_PULSE                :  std_logic;   
   SIGNAL BITSLIP_PULSE            :  std_logic;   
   SIGNAL RESET_SM                 :  std_logic_vector(20 DOWNTO 0);   
   SIGNAL BITSLIP_TO_ISERDES       :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL ICE_TO_ISERDES           :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL INC_TO_ISERDES           :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL ICE_TO_ISERDES_RT        :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL INC_TO_ISERDES_RT        :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL ICE_TO_MONITOR_RT        :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL INC_TO_MONITOR_RT        :  std_logic_vector(15 DOWNTO 0);   
   SIGNAL DATA_TO_MACHINE          :  std_logic_vector(5 DOWNTO 0);   
   SIGNAL DATA_TO_RT               :  std_logic_vector(5 DOWNTO 0);   
   SIGNAL MONITOR_TO_RT            :  std_logic_vector(5 DOWNTO 0);   
   SIGNAL I                        :  integer;   


   SIGNAL ICE_DELAY                :  std_logic;   
   SIGNAL INC_DELAY                :  std_logic;   
   SIGNAL START_ALIGN              :  std_logic;   
   SIGNAL START_ALIGN_RT           :  std_logic;   
   SIGNAL RXCLKDIV_TEMP, RXCLK_TEMP       :  std_logic;   
   SIGNAL BIT_ALIGN_MACHINE_RESET  :  std_logic;

   SIGNAL RT_WINDOW_MONITOR_TRAINING:  std_logic;
   SIGNAL K                        :  integer;   
   SIGNAL TRAINING_DONE_TEMP       :  std_logic;
   SIGNAL RX_MON_RESET       :  std_logic;

SIGNAL  TEMP_TAP_RST_00, TEMP_TAP_RST_01, TEMP_TAP_RST_02,
           TEMP_TAP_RST_03, TEMP_TAP_RST_04, TEMP_TAP_RST_05,
           TEMP_TAP_RST_06, TEMP_TAP_RST_07, TEMP_TAP_RST_08,
           TEMP_TAP_RST_09, TEMP_TAP_RST_10, TEMP_TAP_RST_11,
           TEMP_TAP_RST_12, TEMP_TAP_RST_13, TEMP_TAP_RST_14, 
           TEMP_TAP_RST_15         :  std_logic;
   SIGNAL  TEMP_TAP_CNT_00, TEMP_TAP_CNT_01, TEMP_TAP_CNT_02,
           TEMP_TAP_CNT_03, TEMP_TAP_CNT_04, TEMP_TAP_CNT_05,
           TEMP_TAP_CNT_06, TEMP_TAP_CNT_07, TEMP_TAP_CNT_08,
           TEMP_TAP_CNT_09, TEMP_TAP_CNT_10, TEMP_TAP_CNT_11,
           TEMP_TAP_CNT_12, TEMP_TAP_CNT_13, TEMP_TAP_CNT_14,
           TEMP_TAP_CNT_15         :  std_logic;
   SIGNAL  TEMP_TAP_UD_00, TEMP_TAP_UD_01, TEMP_TAP_UD_02,
           TEMP_TAP_UD_03, TEMP_TAP_UD_04, TEMP_TAP_UD_05,
           TEMP_TAP_UD_06, TEMP_TAP_UD_07, TEMP_TAP_UD_08,
           TEMP_TAP_UD_09, TEMP_TAP_UD_10, TEMP_TAP_UD_11,
           TEMP_TAP_UD_12, TEMP_TAP_UD_13, TEMP_TAP_UD_14,
           TEMP_TAP_UD_15          :  std_logic;
   
SIGNAL  RX_DATA_CE_00, RX_DATA_CE_01, RX_DATA_CE_02, RX_DATA_CE_03 :  std_logic;
SIGNAL  RX_DATA_CE_04, RX_DATA_CE_05, RX_DATA_CE_06, RX_DATA_CE_07 :  std_logic;
SIGNAL  RX_DATA_CE_08, RX_DATA_CE_09, RX_DATA_CE_10, RX_DATA_CE_11 :  std_logic;
SIGNAL  RX_DATA_CE_12, RX_DATA_CE_13, RX_DATA_CE_14, RX_DATA_CE_15 :  std_logic;

SIGNAL  RX_DATA_INC_00, RX_DATA_INC_01, RX_DATA_INC_02, RX_DATA_INC_03 :  std_logic;
SIGNAL  RX_DATA_INC_04, RX_DATA_INC_05, RX_DATA_INC_06, RX_DATA_INC_07 :  std_logic;
SIGNAL  RX_DATA_INC_08, RX_DATA_INC_09, RX_DATA_INC_10, RX_DATA_INC_11 :  std_logic;
SIGNAL  RX_DATA_INC_12, RX_DATA_INC_13, RX_DATA_INC_14, RX_DATA_INC_15 :  std_logic;

SIGNAL   RX_DATA_RESET :  std_logic;
SIGNAL BITSLIP_00, BITSLIP_01, BITSLIP_02, BITSLIP_03 :  std_logic;
SIGNAL BITSLIP_04, BITSLIP_05, BITSLIP_06, BITSLIP_07 :  std_logic;
SIGNAL BITSLIP_08, BITSLIP_09, BITSLIP_10, BITSLIP_11 :  std_logic;
SIGNAL BITSLIP_12, BITSLIP_13, BITSLIP_14, BITSLIP_15 :  std_logic;

SIGNAL MON_BITSLIP_00, MON_BITSLIP_01, MON_BITSLIP_02, MON_BITSLIP_03 :  std_logic;
SIGNAL MON_BITSLIP_04, MON_BITSLIP_05, MON_BITSLIP_06, MON_BITSLIP_07 :  std_logic;
SIGNAL MON_BITSLIP_08, MON_BITSLIP_09, MON_BITSLIP_10, MON_BITSLIP_11 :  std_logic;
SIGNAL MON_BITSLIP_12, MON_BITSLIP_13, MON_BITSLIP_14, MON_BITSLIP_15 :  std_logic;


SIGNAL RX_MON_CE_00, RX_MON_CE_01, RX_MON_CE_02, RX_MON_CE_03  :  std_logic;
SIGNAL RX_MON_CE_04, RX_MON_CE_05, RX_MON_CE_06, RX_MON_CE_07  :  std_logic;
SIGNAL RX_MON_CE_08, RX_MON_CE_09, RX_MON_CE_10, RX_MON_CE_11  :  std_logic;
SIGNAL RX_MON_CE_12, RX_MON_CE_13, RX_MON_CE_14, RX_MON_CE_15  :  std_logic;

SIGNAL RX_MON_INC_00, RX_MON_INC_01, RX_MON_INC_02, RX_MON_INC_03  :  std_logic;
SIGNAL RX_MON_INC_04, RX_MON_INC_05, RX_MON_INC_06, RX_MON_INC_07  :  std_logic;
SIGNAL RX_MON_INC_08, RX_MON_INC_09, RX_MON_INC_10, RX_MON_INC_11  :  std_logic;
SIGNAL RX_MON_INC_12, RX_MON_INC_13, RX_MON_INC_14, RX_MON_INC_15  :  std_logic;

attribute DIFF_TERM : string;  
attribute DIFF_TERM of RX_DATA_IN_00  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_01  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_02  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_03  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_04  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_05  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_06  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_07  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_08  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_09  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_10  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_11  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_12  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_13  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_14  : label is "TRUE";
attribute DIFF_TERM of RX_DATA_IN_15  : label is "TRUE";

BEGIN
   DATA_FROM_ISERDES <= DATA_FROM_ISERDES_TEMP;
   RXCLK <= RXCLK_TEMP;

   TRAINING_DONE <= TRAINING_DONE_TEMP;

   INC_DELAY <= INC_PULSE ;
   ICE_DELAY <= INC_PULSE OR DEC_PULSE ;

   
RXCLKDIV <= RXCLKDIV_TEMP;

   --IDELAYCTRL MODULE

   RX_IDELAYCTRL : IDELAYCTRL 
      PORT MAP (
         RDY => IDELAY_READY,
         REFCLK => CLK200,
         RST => IDELAYCTRL_RESET);   
   
   
   --SOURCE SYNCHRONOUS CLOCK INPUT

   SOURCE_SYNC_CLOCK_IN : IBUFDS 
      GENERIC MAP(
         DIFF_TERM => TRUE, IOSTANDARD =>"LVDS_25") 
      PORT MAP (
         O => CLOCK_RX_BUF,
         I => CLOCK_RX_P,
         IB => CLOCK_RX_N);   
   
   
   --IDELAY IN CLOCK PATH

   ISERDES_CLOCK_RX : IODELAY 
      GENERIC MAP(
         IDELAY_TYPE => "FIXED", IDELAY_VALUE => 0, 
         ODELAY_VALUE => 0, REFCLK_FREQUENCY => 200.00,  
        HIGH_PERFORMANCE_MODE => "TRUE") 
      PORT MAP (
         DATAOUT => CLOCK_RX_ISERDES_OUT,
         IDATAIN => CLOCK_RX_BUF,
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => '0',
         INC => '0',
         C => '0',
         RST => RESET);   
   
   
   --CLOCK BUFFER FOR SERIAL SIDE CLOCK	

   RX_CLK_BUFIO : BUFIO 
      PORT MAP (
         O => RXCLK_TEMP,
         I => CLOCK_RX_ISERDES_OUT);   
   
   
   --CLOCK BUFFER/DIVIDER FOR PARALLEL SIDE CLOCK

   RX_CLK_BUFR : BUFR 
      GENERIC MAP( 
         BUFR_DIVIDE => "3" )
      PORT MAP (
         O => RXCLKDIV_TEMP,
         CE => '1',
         CLR => '0',
         I => CLOCK_RX_ISERDES_OUT);   
   

   -- CHANNEL SELECT LOGIC TO SHARE ALIGNMENT MACHINE 
   -- RESOURCES IN ROUND ROBIN FASHION
   
   PROCESS (RXCLKDIV_TEMP)
   BEGIN
      IF (RXCLKDIV_TEMP'EVENT AND RXCLKDIV_TEMP = '1') THEN
         CASE CHAN_SEL IS
            WHEN "0000" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(5 DOWNTO 0);    
                  INC_TO_ISERDES <= "000000000000000" & INC_FROM_MACHINE;    
                  ICE_TO_ISERDES <= "000000000000000" & ICE_FROM_MACHINE;    
                  BITSLIP_TO_ISERDES <= "000000000000000" &    
                                           BITSLIP_FROM_MACHINE;    
            WHEN "0001" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(11 DOWNTO 6);    
                  INC_TO_ISERDES <= "00000000000000" & INC_FROM_MACHINE & '0';    
                  ICE_TO_ISERDES <= "00000000000000" & ICE_FROM_MACHINE & '0';    
                  BITSLIP_TO_ISERDES <= "00000000000000" & 
                     BITSLIP_FROM_MACHINE & '0';    
            WHEN "0010" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(17 DOWNTO 12);    
                  INC_TO_ISERDES <= "0000000000000" & INC_FROM_MACHINE & "00";    
                  ICE_TO_ISERDES <= "0000000000000" & ICE_FROM_MACHINE & "00";    
                  BITSLIP_TO_ISERDES <= "0000000000000" & 
                     BITSLIP_FROM_MACHINE & "00";    
            WHEN "0011" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(23 DOWNTO 18);    
                  INC_TO_ISERDES <= "000000000000" & INC_FROM_MACHINE & "000";    
                  ICE_TO_ISERDES <= "000000000000" & ICE_FROM_MACHINE & "000";    
                  BITSLIP_TO_ISERDES <= "000000000000" & 
                     BITSLIP_FROM_MACHINE & "000";    
            WHEN "0100" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(29 DOWNTO 24);    
                  INC_TO_ISERDES <= "00000000000" & INC_FROM_MACHINE & "0000";    
                  ICE_TO_ISERDES <= "00000000000" & ICE_FROM_MACHINE & "0000";    
                  BITSLIP_TO_ISERDES <= "00000000000" & 
                     BITSLIP_FROM_MACHINE & "0000";    
            WHEN "0101" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(35 DOWNTO 30);    
                  INC_TO_ISERDES <= "0000000000" & INC_FROM_MACHINE & "00000";    
                  ICE_TO_ISERDES <= "0000000000" & ICE_FROM_MACHINE & "00000";    
                  BITSLIP_TO_ISERDES <= "0000000000" & 
                     BITSLIP_FROM_MACHINE & "00000";    
            WHEN "0110" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(41 DOWNTO 36);    
                  INC_TO_ISERDES <= "000000000" & INC_FROM_MACHINE & "000000";    
                  ICE_TO_ISERDES <= "000000000" & ICE_FROM_MACHINE & "000000";    
                  BITSLIP_TO_ISERDES <= "000000000" & 
                     BITSLIP_FROM_MACHINE & "000000";    
            WHEN "0111" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(47 DOWNTO 42);    
                  INC_TO_ISERDES <= "00000000" & INC_FROM_MACHINE & "0000000";    
                  ICE_TO_ISERDES <= "00000000" & ICE_FROM_MACHINE & "0000000";    
                  BITSLIP_TO_ISERDES <= "00000000" & 
                     BITSLIP_FROM_MACHINE & "0000000";    
            WHEN "1000" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(53 DOWNTO 48);    
                  INC_TO_ISERDES <= "0000000" & INC_FROM_MACHINE & "00000000";    
                  ICE_TO_ISERDES <= "0000000" & ICE_FROM_MACHINE & "00000000";    
                  BITSLIP_TO_ISERDES <= "0000000" & 
                     BITSLIP_FROM_MACHINE & "00000000";    
            WHEN "1001" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(59 DOWNTO 54);    
                  INC_TO_ISERDES <= "000000" & INC_FROM_MACHINE & "000000000";    
                  ICE_TO_ISERDES <= "000000" & ICE_FROM_MACHINE & "000000000";    
                  BITSLIP_TO_ISERDES <= "000000" & 
                     BITSLIP_FROM_MACHINE & "000000000";    
            WHEN "1010" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(65 DOWNTO 60);    
                  INC_TO_ISERDES <= "00000" & INC_FROM_MACHINE & "0000000000";    
                  ICE_TO_ISERDES <= "00000" & ICE_FROM_MACHINE & "0000000000";    
                  BITSLIP_TO_ISERDES <= "00000" & 
                     BITSLIP_FROM_MACHINE & "0000000000";    
            WHEN "1011" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(71 DOWNTO 66);    
                  INC_TO_ISERDES <= "0000" & INC_FROM_MACHINE & "00000000000";    
                  ICE_TO_ISERDES <= "0000" & ICE_FROM_MACHINE & "00000000000";    
                  BITSLIP_TO_ISERDES <= "0000" & BITSLIP_FROM_MACHINE 
                     & "00000000000";    
            WHEN "1100" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(77 DOWNTO 72);    
                  INC_TO_ISERDES <= "000" & INC_FROM_MACHINE & "000000000000";    
                  ICE_TO_ISERDES <= "000" & ICE_FROM_MACHINE & "000000000000";    
                  BITSLIP_TO_ISERDES <= "000" & BITSLIP_FROM_MACHINE 
                     & "000000000000";    
            WHEN "1101" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(83 DOWNTO 78);    
                  INC_TO_ISERDES <= "00" & INC_FROM_MACHINE & "0000000000000";    
                  ICE_TO_ISERDES <= "00" & ICE_FROM_MACHINE & "0000000000000";    
                  BITSLIP_TO_ISERDES <= "00" & BITSLIP_FROM_MACHINE & 
                     "0000000000000";    
            WHEN "1110" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(89 DOWNTO 84);    
                  INC_TO_ISERDES <= '0' & INC_FROM_MACHINE & "00000000000000";    
                  ICE_TO_ISERDES <= '0' & ICE_FROM_MACHINE & "00000000000000";    
                  BITSLIP_TO_ISERDES <= '0' & BITSLIP_FROM_MACHINE & 
                     "00000000000000";    
            WHEN "1111" =>
                  DATA_TO_MACHINE <= DATA_FROM_ISERDES_TEMP(95 DOWNTO 90);    
                  INC_TO_ISERDES <= INC_FROM_MACHINE & "000000000000000";    
                  ICE_TO_ISERDES <= ICE_FROM_MACHINE & "000000000000000";    
                  BITSLIP_TO_ISERDES <= BITSLIP_FROM_MACHINE & 
                     "000000000000000";    
            WHEN OTHERS => NULL;
            
         END CASE;
      END IF;
   END PROCESS;

--MACHINE THAT ALLOCATES BIT_ALIGN_MACHINE TO EACH OF THE 16 DATA CHANNELS, ONE --AT A TIME 
   RESOURCE_SHARING_CONTROL_0 : RESOURCE_SHARING_CONTROL 
      PORT MAP (
         CHAN_SEL => CHAN_SEL,
         ALL_CHANNELS_ALIGNED => TRAINING_DONE_TEMP,
         DATA_ALIGNED => DATA_ALIGNED,
         START_ALIGN => START_ALIGN,
         CLK => RXCLKDIV_TEMP,
         RST => RESET,
         REPEAT_PROC => '0');   
   

		 BIT_ALIGN_MACHINE_RESET <= RESET OR RESET_SM(15);

--MACHINE THAT ADJUSTS DELAY OF A SINGLE DATA CHANNEL TO OPTIMIZE SAMPLING POINT 
   BIT_ALIGN_MACHINE_0 : BIT_ALIGN_MACHINE 
      PORT MAP (
         RXCLKDIV => RXCLKDIV_TEMP,
         RXDATA => DATA_TO_MACHINE,
         RST => BIT_ALIGN_MACHINE_RESET,
         USE_BITSLIP => '1',
         SAP => START_ALIGN,
         INC => INC_FROM_MACHINE,
         ICE => ICE_FROM_MACHINE,
         BITSLIP => BITSLIP_FROM_MACHINE,
         DATA_ALIGNED => DATA_ALIGNED);   
   
--MACHINE THAT ALLOCATES RT_WINDOW_MONITOR TO EACH OF THE 16 DATA CHANNELS, ONE --AT A TIME 
   RESOURCE_SHARING_CONTROL_1 : RESOURCE_SHARING_CONTROL 
      PORT MAP (
         CHAN_SEL => CHAN_SEL_RT,
         ALL_CHANNELS_ALIGNED => open,
         DATA_ALIGNED => DATA_ALIGNED_RT,
         START_ALIGN => START_ALIGN_RT,
         CLK => RXCLKDIV_TEMP,
         RST => RESET,
         REPEAT_PROC => '1');   
   
--MACHINE THAT ADJUSTS DATA CHANNEL DELAYS IN REAL-TIME TO ACCOUNT FOR VT 
--VARIATION

RT_WINDOW_MONITOR_TRAINING <= (TRAINING_DONE_TEMP AND RT_MANUAL_DISABLE);

   RT_WINDOW_MONITOR_0 : RT_WINDOW_MONITOR 
      PORT MAP (
         CLOCK => RXCLKDIV_TEMP,
         RESET => RESET,
         TRAINING_DONE => RT_WINDOW_MONITOR_TRAINING,
         START => START_ALIGN_RT,
         DATA_MASTER => DATA_TO_RT,
         DATA_MONITOR => MONITOR_TO_RT,
         INC_MONITOR => INC_MONITOR,
         ICE_MONITOR => ICE_MONITOR,
         INC_DATABUS => INC_DATABUS,
         ICE_DATABUS => ICE_DATABUS,
         DATA_ALIGNED_RT => DATA_ALIGNED_RT);   
   

   --CHANNEL SELECT LOGIC TO SHARE RT_WINDOW_MONITOR IN ROUND ROBIN FASHION
   
   PROCESS (RXCLKDIV_TEMP)
   BEGIN
      IF (RXCLKDIV_TEMP'EVENT AND RXCLKDIV_TEMP  = '1') THEN
         CASE CHAN_SEL_RT IS
            WHEN "0000" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(5 DOWNTO 0);  
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(5 DOWNTO 0); 
                     INC_TO_ISERDES_RT <= "000000000000000" & INC_DATABUS;    
                     ICE_TO_ISERDES_RT <= "000000000000000" & ICE_DATABUS;    
                     INC_TO_MONITOR_RT <= "000000000000000" & INC_MONITOR;    
                     ICE_TO_MONITOR_RT <= "000000000000000" & ICE_MONITOR;    
            WHEN "0001" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(11 DOWNTO 6); 
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(11 DOWNTO 6);    
                     INC_TO_ISERDES_RT <= "00000000000000" & INC_DATABUS & '0';    
                     ICE_TO_ISERDES_RT <= "00000000000000" & ICE_DATABUS & '0';    
                     INC_TO_MONITOR_RT <= "00000000000000" & INC_MONITOR & '0';    
                     ICE_TO_MONITOR_RT <= "00000000000000" & ICE_MONITOR & '0';    
            WHEN "0010" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(17 DOWNTO 12);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(17 DOWNTO 12);    
                     INC_TO_ISERDES_RT <= "0000000000000" & INC_DATABUS & "00";    
                     ICE_TO_ISERDES_RT <= "0000000000000" & ICE_DATABUS & "00";    
                     INC_TO_MONITOR_RT <= "0000000000000" & INC_MONITOR & "00";    
                     ICE_TO_MONITOR_RT <= "0000000000000" & ICE_MONITOR & "00";    
            WHEN "0011" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(23 DOWNTO 18);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(23 DOWNTO 18);    
                     INC_TO_ISERDES_RT <= "000000000000" & INC_DATABUS & "000";    
                     ICE_TO_ISERDES_RT <= "000000000000" & ICE_DATABUS & "000";    
                     INC_TO_MONITOR_RT <= "000000000000" & INC_MONITOR & "000";    
                     ICE_TO_MONITOR_RT <= "000000000000" & ICE_MONITOR & "000";    
            WHEN "0100" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(29 DOWNTO 24);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(29 DOWNTO 24);    
                     INC_TO_ISERDES_RT <= "00000000000" & INC_DATABUS & "0000";    
                     ICE_TO_ISERDES_RT <= "00000000000" & ICE_DATABUS & "0000";    
                     INC_TO_MONITOR_RT <= "00000000000" & INC_MONITOR & "0000";    
                     ICE_TO_MONITOR_RT <= "00000000000" & ICE_MONITOR & "0000";    
            WHEN "0101" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(35 DOWNTO 30);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(35 DOWNTO 30);    
                     INC_TO_ISERDES_RT <= "0000000000" & INC_DATABUS & "00000";    
                     ICE_TO_ISERDES_RT <= "0000000000" & ICE_DATABUS & "00000";    
                     INC_TO_MONITOR_RT <= "0000000000" & INC_MONITOR & "00000";    
                     ICE_TO_MONITOR_RT <= "0000000000" & ICE_MONITOR & "00000";    
            WHEN "0110" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(41 DOWNTO 36);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(41 DOWNTO 36);    
                     INC_TO_ISERDES_RT <= "000000000" & INC_DATABUS & "000000";    
                     ICE_TO_ISERDES_RT <= "000000000" & ICE_DATABUS & "000000";    
                     INC_TO_MONITOR_RT <= "000000000" & INC_MONITOR & "000000";    
                     ICE_TO_MONITOR_RT <= "000000000" & ICE_MONITOR & "000000";    
            WHEN "0111" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(47 DOWNTO 42);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(47 DOWNTO 42);    
                     INC_TO_ISERDES_RT <= "00000000" & INC_DATABUS & "0000000";    
                     ICE_TO_ISERDES_RT <= "00000000" & ICE_DATABUS & "0000000";    
                     INC_TO_MONITOR_RT <= "00000000" & INC_MONITOR & "0000000";    
                     ICE_TO_MONITOR_RT <= "00000000" & ICE_MONITOR & "0000000";    
            WHEN "1000" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(53 DOWNTO 48);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(53 DOWNTO 48);    
                     INC_TO_ISERDES_RT <= "0000000" & INC_DATABUS & "00000000";    
                     ICE_TO_ISERDES_RT <= "0000000" & ICE_DATABUS & "00000000";    
                     INC_TO_MONITOR_RT <= "0000000" & INC_MONITOR & "00000000";    
                     ICE_TO_MONITOR_RT <= "0000000" & ICE_MONITOR & "00000000";    
            WHEN "1001" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(59 DOWNTO 54);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(59 DOWNTO 54);    
                     INC_TO_ISERDES_RT <= "000000" & INC_DATABUS & "000000000";    
                     ICE_TO_ISERDES_RT <= "000000" & ICE_DATABUS & "000000000";    
                     INC_TO_MONITOR_RT <= "000000" & INC_MONITOR & "000000000";    
                     ICE_TO_MONITOR_RT <= "000000" & ICE_MONITOR & "000000000";    
            WHEN "1010" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(65 DOWNTO 60);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(65 DOWNTO 60);    
                     INC_TO_ISERDES_RT <= "00000" & INC_DATABUS & "0000000000";    
                     ICE_TO_ISERDES_RT <= "00000" & ICE_DATABUS & "0000000000";    
                     INC_TO_MONITOR_RT <= "00000" & INC_MONITOR & "0000000000";    
                     ICE_TO_MONITOR_RT <= "00000" & ICE_MONITOR & "0000000000";    
            WHEN "1011" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(71 DOWNTO 66);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(71 DOWNTO 66);    
                     INC_TO_ISERDES_RT <= "0000" & INC_DATABUS & "00000000000";    
                     ICE_TO_ISERDES_RT <= "0000" & ICE_DATABUS & "00000000000";    
                     INC_TO_MONITOR_RT <= "0000" & INC_MONITOR & "00000000000";    
                     ICE_TO_MONITOR_RT <= "0000" & ICE_MONITOR & "00000000000";    
            WHEN "1100" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(77 DOWNTO 72);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(77 DOWNTO 72);    
                     INC_TO_ISERDES_RT <= "000" & INC_DATABUS & "000000000000";    
                     ICE_TO_ISERDES_RT <= "000" & ICE_DATABUS & "000000000000";    
                     INC_TO_MONITOR_RT <= "000" & INC_MONITOR & "000000000000";    
                     ICE_TO_MONITOR_RT <= "000" & ICE_MONITOR & "000000000000";    
            WHEN "1101" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(83 DOWNTO 78);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(83 DOWNTO 78);    
                     INC_TO_ISERDES_RT <= "00" & INC_DATABUS & "0000000000000";    
                     ICE_TO_ISERDES_RT <= "00" & ICE_DATABUS & "0000000000000";    
                     INC_TO_MONITOR_RT <= "00" & INC_MONITOR & "0000000000000";    
                     ICE_TO_MONITOR_RT <= "00" & ICE_MONITOR & "0000000000000";    
            WHEN "1110" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(89 DOWNTO 84);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(89 DOWNTO 84);    
                     INC_TO_ISERDES_RT <= '0' & INC_DATABUS & "00000000000000";    
                     ICE_TO_ISERDES_RT <= '0' & ICE_DATABUS & "00000000000000";    
                     INC_TO_MONITOR_RT <= '0' & INC_MONITOR & "00000000000000";    
                     ICE_TO_MONITOR_RT <= '0' & ICE_MONITOR & "00000000000000";    
            WHEN "1111" =>
                     DATA_TO_RT <= DATA_FROM_ISERDES_TEMP(95 DOWNTO 90);    
                     MONITOR_TO_RT <= DATA_FROM_ISERDES_MON(95 DOWNTO 90);    
                     INC_TO_ISERDES_RT <= INC_DATABUS & "000000000000000";    
                     ICE_TO_ISERDES_RT <= ICE_DATABUS & "000000000000000";    
                     INC_TO_MONITOR_RT <= INC_MONITOR & "000000000000000";    
                     ICE_TO_MONITOR_RT <= ICE_MONITOR & "000000000000000";    
            WHEN OTHERS => NULL;
            
         END CASE;
      END IF;
   END PROCESS;

   --SHORTEN EACH EXTERNAL INC AND DEC PULSE TO ONE RXCLKDIV CYCLE
   
   PROCESS (RXCLKDIV_TEMP)
   BEGIN
      IF (RXCLKDIV_TEMP'EVENT AND RXCLKDIV_TEMP = '1') THEN
         INC_CAPTURE(0) <= INC_PAD;    -- ASYNCHRONOUS ENTRY POINT
         DEC_CAPTURE(0) <= DEC_PAD;    
         BITSLIP_CAPTURE(0) <= BITSLIP_PAD;    
         FOR I IN 0 TO 3 - 1 LOOP
            INC_CAPTURE(I + 1) <= INC_CAPTURE(I);    -- METASTABLE FLIP-FLOPS
            DEC_CAPTURE(I + 1) <= DEC_CAPTURE(I);    
            BITSLIP_CAPTURE(I + 1) <= BITSLIP_CAPTURE(I);    
         END LOOP;
         INC_PULSE <= INC_CAPTURE(2) AND NOT INC_CAPTURE(3);    
                                -- STABLE, SINGLE PULSE
         DEC_PULSE <= DEC_CAPTURE(2) AND NOT DEC_CAPTURE(3);    
         BITSLIP_PULSE <= BITSLIP_CAPTURE(2) AND NOT BITSLIP_CAPTURE(3); 
      END IF;
   END PROCESS;

   --KEEP TRACK OF CURRENT TAP SETTING OF IDELAY IN DATA PATH OF CHANNELS 0-15

   TEMP_TAP_RST_00 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_00 <= ICE_DELAY OR ICE_TO_ISERDES(00) OR ICE_TO_ISERDES_RT(00);
   TEMP_TAP_UD_00 <= INC_DELAY OR INC_TO_ISERDES(00) OR INC_TO_ISERDES_RT(00);
   TAP_COUNTER_00 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_00,
         count => TEMP_TAP_CNT_00,
         ud => TEMP_TAP_UD_00,
         counter_value => TAP_00);   
   
   TEMP_TAP_RST_01 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_01 <= ICE_DELAY OR ICE_TO_ISERDES(01) OR ICE_TO_ISERDES_RT(01);
   TEMP_TAP_UD_01 <= INC_DELAY OR INC_TO_ISERDES(01) OR INC_TO_ISERDES_RT(01);
   TAP_COUNTER_01 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_01,
         count => TEMP_TAP_CNT_01,
         ud => TEMP_TAP_UD_01,
         counter_value => TAP_01);   
   
   TEMP_TAP_RST_02 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_02 <= ICE_DELAY OR ICE_TO_ISERDES(02) OR ICE_TO_ISERDES_RT(02);
   TEMP_TAP_UD_02 <= INC_DELAY OR INC_TO_ISERDES(02) OR INC_TO_ISERDES_RT(02);
   TAP_COUNTER_02 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_02,
         count => TEMP_TAP_CNT_02,
         ud => TEMP_TAP_UD_02,
         counter_value => TAP_02);   
   
   TEMP_TAP_RST_03 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_03 <= ICE_DELAY OR ICE_TO_ISERDES(03) OR ICE_TO_ISERDES_RT(03);
   TEMP_TAP_UD_03 <= INC_DELAY OR INC_TO_ISERDES(03) OR INC_TO_ISERDES_RT(03);
   TAP_COUNTER_03 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_03,
         count => TEMP_TAP_CNT_03,
         ud => TEMP_TAP_UD_03,
         counter_value => TAP_03);   
   
   TEMP_TAP_RST_04 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_04 <= ICE_DELAY OR ICE_TO_ISERDES(04) OR ICE_TO_ISERDES_RT(04);
   TEMP_TAP_UD_04 <= INC_DELAY OR INC_TO_ISERDES(04) OR INC_TO_ISERDES_RT(04);
   TAP_COUNTER_04 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_04,
         count => TEMP_TAP_CNT_04,
         ud => TEMP_TAP_UD_04,
         counter_value => TAP_04);   
   
   TEMP_TAP_RST_05 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_05 <= ICE_DELAY OR ICE_TO_ISERDES(05) OR ICE_TO_ISERDES_RT(05);
   TEMP_TAP_UD_05 <= INC_DELAY OR INC_TO_ISERDES(05) OR INC_TO_ISERDES_RT(05);
   TAP_COUNTER_05 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_05,
         count => TEMP_TAP_CNT_05,
         ud => TEMP_TAP_UD_05,
         counter_value => TAP_05);   
   
   TEMP_TAP_RST_06 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_06 <= ICE_DELAY OR ICE_TO_ISERDES(06) OR ICE_TO_ISERDES_RT(06);
   TEMP_TAP_UD_06 <= INC_DELAY OR INC_TO_ISERDES(06) OR INC_TO_ISERDES_RT(06);
   TAP_COUNTER_06 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_06,
         count => TEMP_TAP_CNT_06,
         ud => TEMP_TAP_UD_06,
         counter_value => TAP_06);   
   
   TEMP_TAP_RST_07 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_07 <= ICE_DELAY OR ICE_TO_ISERDES(07) OR ICE_TO_ISERDES_RT(07);
   TEMP_TAP_UD_07 <= INC_DELAY OR INC_TO_ISERDES(07) OR INC_TO_ISERDES_RT(07);
   TAP_COUNTER_07 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_07,
         count => TEMP_TAP_CNT_07,
         ud => TEMP_TAP_UD_07,
         counter_value => TAP_07);   
   
   TEMP_TAP_RST_08 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_08 <= ICE_DELAY OR ICE_TO_ISERDES(08) OR ICE_TO_ISERDES_RT(08);
   TEMP_TAP_UD_08 <= INC_DELAY OR INC_TO_ISERDES(08) OR INC_TO_ISERDES_RT(08);
   TAP_COUNTER_08 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_08,
         count => TEMP_TAP_CNT_08,
         ud => TEMP_TAP_UD_08,
         counter_value => TAP_08);   
   
   TEMP_TAP_RST_09 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_09 <= ICE_DELAY OR ICE_TO_ISERDES(09) OR ICE_TO_ISERDES_RT(09);
   TEMP_TAP_UD_09 <= INC_DELAY OR INC_TO_ISERDES(09) OR INC_TO_ISERDES_RT(09);
   TAP_COUNTER_09 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_09,
         count => TEMP_TAP_CNT_09,
         ud => TEMP_TAP_UD_09,
         counter_value => TAP_09);   
   
   TEMP_TAP_RST_10 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_10 <= ICE_DELAY OR ICE_TO_ISERDES(10) OR ICE_TO_ISERDES_RT(10);
   TEMP_TAP_UD_10 <= INC_DELAY OR INC_TO_ISERDES(10) OR INC_TO_ISERDES_RT(10);
   TAP_COUNTER_10 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_10,
         count => TEMP_TAP_CNT_10,
         ud => TEMP_TAP_UD_10,
         counter_value => TAP_10);   
   
   TEMP_TAP_RST_11 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_11 <= ICE_DELAY OR ICE_TO_ISERDES(11) OR ICE_TO_ISERDES_RT(11);
   TEMP_TAP_UD_11 <= INC_DELAY OR INC_TO_ISERDES(11) OR INC_TO_ISERDES_RT(11);
   TAP_COUNTER_11 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_11,
         count => TEMP_TAP_CNT_11,
         ud => TEMP_TAP_UD_11,
         counter_value => TAP_11);   
   
   TEMP_TAP_RST_12 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_12 <= ICE_DELAY OR ICE_TO_ISERDES(12) OR ICE_TO_ISERDES_RT(12);
   TEMP_TAP_UD_12 <= INC_DELAY OR INC_TO_ISERDES(12) OR INC_TO_ISERDES_RT(12);
   TAP_COUNTER_12 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_12,
         count => TEMP_TAP_CNT_12,
         ud => TEMP_TAP_UD_12,
         counter_value => TAP_12);   
   
   TEMP_TAP_RST_13 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_13 <= ICE_DELAY OR ICE_TO_ISERDES(13) OR ICE_TO_ISERDES_RT(13);
   TEMP_TAP_UD_13 <= INC_DELAY OR INC_TO_ISERDES(13) OR INC_TO_ISERDES_RT(13);
   TAP_COUNTER_13 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_13,
         count => TEMP_TAP_CNT_13,
         ud => TEMP_TAP_UD_13,
         counter_value => TAP_13);   
   
   TEMP_TAP_RST_14 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_14 <= ICE_DELAY OR ICE_TO_ISERDES(14) OR ICE_TO_ISERDES_RT(14);
   TEMP_TAP_UD_14 <= INC_DELAY OR INC_TO_ISERDES(14) OR INC_TO_ISERDES_RT(14);
   TAP_COUNTER_14 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_14,
         count => TEMP_TAP_CNT_14,
         ud => TEMP_TAP_UD_14,
         counter_value => TAP_14);   
   
   TEMP_TAP_RST_15 <= IDLY_RESET OR RESET;
   TEMP_TAP_CNT_15 <= ICE_DELAY OR ICE_TO_ISERDES(15) OR ICE_TO_ISERDES_RT(15);
   TEMP_TAP_UD_15 <= INC_DELAY OR INC_TO_ISERDES(15) OR INC_TO_ISERDES_RT(15);
   TAP_COUNTER_15 : COUNT_TO_64 
      PORT MAP (
         clk => RXCLKDIV_TEMP,
         rst => TEMP_TAP_RST_15,
         count => TEMP_TAP_CNT_15,
         ud => TEMP_TAP_UD_15,
         counter_value => TAP_15); 


   --CIRCUIT TO PRODUCE RESET DELAYED BY 20 CYCLES FOR BIT_ALIGN_MACHINE

   PROCESS (RXCLKDIV_TEMP)
   BEGIN
      IF (RXCLKDIV_TEMP'EVENT AND RXCLKDIV_TEMP = '1') THEN
         RESET_SM(0) <= RESET;    
         FOR K IN 0 TO 20 - 1 LOOP
            RESET_SM(K + 1) <= RESET_SM(K);    
         END LOOP;
      END IF;
   END PROCESS;
   
   --DATA INPUT BUFFERS WITH DUAL OUTPUTS (ONE INVERTED AND ONE NOT INVERTED)

   RX_DATA_IN_00 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 
      PORT MAP (
         O => DATA_RX_BUF(00),
         OB => DATA_RX_BUF_MON(00),
         I => DATA_RX_P(00),
         IB => DATA_RX_N(00));   
   

   RX_DATA_IN_01 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(01),
         OB => DATA_RX_BUF_MON(01),
         I => DATA_RX_P(01),
         IB => DATA_RX_N(01));   
   

   RX_DATA_IN_02 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(02),
         OB => DATA_RX_BUF_MON(02),
         I => DATA_RX_P(02),
         IB => DATA_RX_N(02));   
   

   RX_DATA_IN_03 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(03),
         OB => DATA_RX_BUF_MON(03),
         I => DATA_RX_P(03),
         IB => DATA_RX_N(03));   
   

   RX_DATA_IN_04 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(04),
         OB => DATA_RX_BUF_MON(04),
         I => DATA_RX_P(04),
         IB => DATA_RX_N(04));   
   

   RX_DATA_IN_05 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(05),
         OB => DATA_RX_BUF_MON(05),
         I => DATA_RX_P(05),
         IB => DATA_RX_N(05));   
   

   RX_DATA_IN_06 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(06),
         OB => DATA_RX_BUF_MON(06),
         I => DATA_RX_P(06),
         IB => DATA_RX_N(06));   
   

   RX_DATA_IN_07 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(07),
         OB => DATA_RX_BUF_MON(07),
         I => DATA_RX_P(07),
         IB => DATA_RX_N(07));   
   

   RX_DATA_IN_08 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(08),
         OB => DATA_RX_BUF_MON(08),
         I => DATA_RX_P(08),
         IB => DATA_RX_N(08));   
   

   RX_DATA_IN_09 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(09),
         OB => DATA_RX_BUF_MON(09),
         I => DATA_RX_P(09),
         IB => DATA_RX_N(09));   
   

   RX_DATA_IN_10 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(10),
         OB => DATA_RX_BUF_MON(10),
         I => DATA_RX_P(10),
         IB => DATA_RX_N(10));   
   

   RX_DATA_IN_11 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(11),
         OB => DATA_RX_BUF_MON(11),
         I => DATA_RX_P(11),
         IB => DATA_RX_N(11));   
   

   RX_DATA_IN_12 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(12),
         OB => DATA_RX_BUF_MON(12),
         I => DATA_RX_P(12),
         IB => DATA_RX_N(12));   
   

   RX_DATA_IN_13 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(13),
         OB => DATA_RX_BUF_MON(13),
         I => DATA_RX_P(13),
         IB => DATA_RX_N(13));   
   

   RX_DATA_IN_14 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(14),
         OB => DATA_RX_BUF_MON(14),
         I => DATA_RX_P(14),
         IB => DATA_RX_N(14));   
   

   RX_DATA_IN_15 : IBUFDS_DIFF_OUT 
      GENERIC MAP(
         IOSTANDARD =>"LVDS_25") 

      PORT MAP (
         O => DATA_RX_BUF(15),
         OB => DATA_RX_BUF_MON(15),
         I => DATA_RX_P(15),
         IB => DATA_RX_N(15));   


   --MASTER SIDE IODELAYS

   RX_DATA_CE_00 <= ICE_DELAY OR ICE_TO_ISERDES(00) OR ICE_TO_ISERDES_RT(00);
   RX_DATA_INC_00 <= INC_DELAY OR INC_TO_ISERDES(00) OR INC_TO_ISERDES_RT(00);
   RX_DATA_RESET <= IDLY_RESET OR RESET;

   IODELAY_RX_DATA_00 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(00),
         IDATAIN => DATA_RX_BUF(00),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_00,
         INC => RX_DATA_INC_00,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_01 <= ICE_DELAY OR ICE_TO_ISERDES(01) OR ICE_TO_ISERDES_RT(01);
   RX_DATA_INC_01 <= INC_DELAY OR INC_TO_ISERDES(01) OR INC_TO_ISERDES_RT(01);

   IODELAY_RX_DATA_01 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(01),
         IDATAIN => DATA_RX_BUF(01),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_01,
         INC => RX_DATA_INC_01,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_02 <= ICE_DELAY OR ICE_TO_ISERDES(02) OR ICE_TO_ISERDES_RT(02);
   RX_DATA_INC_02 <= INC_DELAY OR INC_TO_ISERDES(02) OR INC_TO_ISERDES_RT(02);

   IODELAY_RX_DATA_02 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(02),
         IDATAIN => DATA_RX_BUF(02),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_02,
         INC => RX_DATA_INC_02,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_03 <= ICE_DELAY OR ICE_TO_ISERDES(03) OR ICE_TO_ISERDES_RT(03);
   RX_DATA_INC_03 <= INC_DELAY OR INC_TO_ISERDES(03) OR INC_TO_ISERDES_RT(03);

   IODELAY_RX_DATA_03 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(03),
         IDATAIN => DATA_RX_BUF(03),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_03,
         INC => RX_DATA_INC_03,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_04 <= ICE_DELAY OR ICE_TO_ISERDES(04) OR ICE_TO_ISERDES_RT(04);
   RX_DATA_INC_04 <= INC_DELAY OR INC_TO_ISERDES(04) OR INC_TO_ISERDES_RT(04);


   IODELAY_RX_DATA_04 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(04),
         IDATAIN => DATA_RX_BUF(04),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_04,
         INC => RX_DATA_INC_04,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_05 <= ICE_DELAY OR ICE_TO_ISERDES(05) OR ICE_TO_ISERDES_RT(05);
   RX_DATA_INC_05 <= INC_DELAY OR INC_TO_ISERDES(05) OR INC_TO_ISERDES_RT(05);

   IODELAY_RX_DATA_05 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(05),
         IDATAIN => DATA_RX_BUF(05),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_05,
         INC => RX_DATA_INC_05,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_06 <= ICE_DELAY OR ICE_TO_ISERDES(06) OR ICE_TO_ISERDES_RT(06);
   RX_DATA_INC_06 <= INC_DELAY OR INC_TO_ISERDES(06) OR INC_TO_ISERDES_RT(06);

   IODELAY_RX_DATA_06 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(06),
         IDATAIN => DATA_RX_BUF(06),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_06,
         INC => RX_DATA_INC_06,
        C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_07 <= ICE_DELAY OR ICE_TO_ISERDES(07) OR ICE_TO_ISERDES_RT(07);
   RX_DATA_INC_07 <= INC_DELAY OR INC_TO_ISERDES(07) OR INC_TO_ISERDES_RT(07);

   IODELAY_RX_DATA_07 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(07),
         IDATAIN => DATA_RX_BUF(07),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_07,
         INC => RX_DATA_INC_07,
        C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_08 <= ICE_DELAY OR ICE_TO_ISERDES(08) OR ICE_TO_ISERDES_RT(08);
   RX_DATA_INC_08 <= INC_DELAY OR INC_TO_ISERDES(08) OR INC_TO_ISERDES_RT(08);

   IODELAY_RX_DATA_08 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(08),
         IDATAIN => DATA_RX_BUF(08),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_08,
         INC => RX_DATA_INC_08,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_09 <= ICE_DELAY OR ICE_TO_ISERDES(09) OR ICE_TO_ISERDES_RT(09);
   RX_DATA_INC_09 <= INC_DELAY OR INC_TO_ISERDES(09) OR INC_TO_ISERDES_RT(09);

   IODELAY_RX_DATA_09 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(09),
         IDATAIN => DATA_RX_BUF(09),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_09,
         INC => RX_DATA_INC_09,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_10 <= ICE_DELAY OR ICE_TO_ISERDES(10) OR ICE_TO_ISERDES_RT(10);
   RX_DATA_INC_10 <= INC_DELAY OR INC_TO_ISERDES(10) OR INC_TO_ISERDES_RT(10);

   IODELAY_RX_DATA_10 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(10),
         IDATAIN => DATA_RX_BUF(10),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_10,
         INC => RX_DATA_INC_10,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_11 <= ICE_DELAY OR ICE_TO_ISERDES(11) OR ICE_TO_ISERDES_RT(11);
   RX_DATA_INC_11 <= INC_DELAY OR INC_TO_ISERDES(11) OR INC_TO_ISERDES_RT(11);

   IODELAY_RX_DATA_11 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(11),
         IDATAIN => DATA_RX_BUF(11),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_11,
         INC => RX_DATA_INC_11,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_12 <= ICE_DELAY OR ICE_TO_ISERDES(12) OR ICE_TO_ISERDES_RT(12);
   RX_DATA_INC_12 <= INC_DELAY OR INC_TO_ISERDES(12) OR INC_TO_ISERDES_RT(12);

   IODELAY_RX_DATA_12 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(12),
         IDATAIN => DATA_RX_BUF(12),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_12,
         INC => RX_DATA_INC_12,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_13 <= ICE_DELAY OR ICE_TO_ISERDES(13) OR ICE_TO_ISERDES_RT(13);
   RX_DATA_INC_13 <= INC_DELAY OR INC_TO_ISERDES(13) OR INC_TO_ISERDES_RT(13);

   IODELAY_RX_DATA_13 : IODELAY 
       GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(13),
         IDATAIN => DATA_RX_BUF(13),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_13,
         INC => RX_DATA_INC_13,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_14 <= ICE_DELAY OR ICE_TO_ISERDES(14) OR ICE_TO_ISERDES_RT(14);
   RX_DATA_INC_14 <= INC_DELAY OR INC_TO_ISERDES(14) OR INC_TO_ISERDES_RT(14);

   IODELAY_RX_DATA_14 : IODELAY 
      GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(14),
         IDATAIN => DATA_RX_BUF(14),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_14,
         INC => RX_DATA_INC_14,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   
   RX_DATA_CE_15 <= ICE_DELAY OR ICE_TO_ISERDES(15) OR ICE_TO_ISERDES_RT(15);
   RX_DATA_INC_15 <= INC_DELAY OR INC_TO_ISERDES(15) OR INC_TO_ISERDES_RT(15);

   IODELAY_RX_DATA_15 : IODELAY 
       GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
      )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY(15),
         IDATAIN => DATA_RX_BUF(15),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_DATA_CE_15,
         INC => RX_DATA_INC_15,
         C => RXCLKDIV_TEMP,
         RST => RX_DATA_RESET);   
   

   --MASTER SIDE ISERDES                                                                                                    

   BITSLIP_00 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(00);

   ISERDES_RX_DATA_00 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(005),
         Q2 => DATA_FROM_ISERDES_TEMP(004),
         Q3 => DATA_FROM_ISERDES_TEMP(003),
         Q4 => DATA_FROM_ISERDES_TEMP(002),
         Q5 => DATA_FROM_ISERDES_TEMP(001),
         Q6 => DATA_FROM_ISERDES_TEMP(000),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_00,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(00),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
  BITSLIP_01 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(01);

   ISERDES_RX_DATA_01 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6,  
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(011),
         Q2 => DATA_FROM_ISERDES_TEMP(010),
         Q3 => DATA_FROM_ISERDES_TEMP(009),
         Q4 => DATA_FROM_ISERDES_TEMP(008),
         Q5 => DATA_FROM_ISERDES_TEMP(007),
         Q6 => DATA_FROM_ISERDES_TEMP(006),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_01,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(01),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_02 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(02);

   ISERDES_RX_DATA_02 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6,  
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(017),
         Q2 => DATA_FROM_ISERDES_TEMP(016),
         Q3 => DATA_FROM_ISERDES_TEMP(015),
         Q4 => DATA_FROM_ISERDES_TEMP(014),
         Q5 => DATA_FROM_ISERDES_TEMP(013),
         Q6 => DATA_FROM_ISERDES_TEMP(012),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_02,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(02),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_03 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(03);

   ISERDES_RX_DATA_03 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(023),
         Q2 => DATA_FROM_ISERDES_TEMP(022),
         Q3 => DATA_FROM_ISERDES_TEMP(021),
         Q4 => DATA_FROM_ISERDES_TEMP(020),
         Q5 => DATA_FROM_ISERDES_TEMP(019),
         Q6 => DATA_FROM_ISERDES_TEMP(018),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_03,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(03),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_04 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(04);

   ISERDES_RX_DATA_04 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6,  
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(029),
         Q2 => DATA_FROM_ISERDES_TEMP(028),
         Q3 => DATA_FROM_ISERDES_TEMP(027),
         Q4 => DATA_FROM_ISERDES_TEMP(026),
         Q5 => DATA_FROM_ISERDES_TEMP(025),
         Q6 => DATA_FROM_ISERDES_TEMP(024),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_04,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(04),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_05 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(05);

   ISERDES_RX_DATA_05 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6,  
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(035),
         Q2 => DATA_FROM_ISERDES_TEMP(034),
         Q3 => DATA_FROM_ISERDES_TEMP(033),
         Q4 => DATA_FROM_ISERDES_TEMP(032),
         Q5 => DATA_FROM_ISERDES_TEMP(031),
         Q6 => DATA_FROM_ISERDES_TEMP(030),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_05,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(05),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_06 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(06);

   ISERDES_RX_DATA_06 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(041),
         Q2 => DATA_FROM_ISERDES_TEMP(040),
         Q3 => DATA_FROM_ISERDES_TEMP(039),
         Q4 => DATA_FROM_ISERDES_TEMP(038),
         Q5 => DATA_FROM_ISERDES_TEMP(037),
         Q6 => DATA_FROM_ISERDES_TEMP(036),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_06,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(06),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
  BITSLIP_07 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(07);

   ISERDES_RX_DATA_07 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(047),
         Q2 => DATA_FROM_ISERDES_TEMP(046),
         Q3 => DATA_FROM_ISERDES_TEMP(045),
         Q4 => DATA_FROM_ISERDES_TEMP(044),
         Q5 => DATA_FROM_ISERDES_TEMP(043),
         Q6 => DATA_FROM_ISERDES_TEMP(042),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_07,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(07),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_08 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(08);

   ISERDES_RX_DATA_08 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(053),
         Q2 => DATA_FROM_ISERDES_TEMP(052),
         Q3 => DATA_FROM_ISERDES_TEMP(051),
         Q4 => DATA_FROM_ISERDES_TEMP(050),
         Q5 => DATA_FROM_ISERDES_TEMP(049),
         Q6 => DATA_FROM_ISERDES_TEMP(048),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_08,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(08),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_09 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(09);

   ISERDES_RX_DATA_09 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(059),
         Q2 => DATA_FROM_ISERDES_TEMP(058),
         Q3 => DATA_FROM_ISERDES_TEMP(057),
         Q4 => DATA_FROM_ISERDES_TEMP(056),
         Q5 => DATA_FROM_ISERDES_TEMP(055),
         Q6 => DATA_FROM_ISERDES_TEMP(054),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_09,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(09),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_10 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(10);

   ISERDES_RX_DATA_10 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(065),
         Q2 => DATA_FROM_ISERDES_TEMP(064),
         Q3 => DATA_FROM_ISERDES_TEMP(063),
         Q4 => DATA_FROM_ISERDES_TEMP(062),
         Q5 => DATA_FROM_ISERDES_TEMP(061),
         Q6 => DATA_FROM_ISERDES_TEMP(060),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_10,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(10),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_11 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(11);

   ISERDES_RX_DATA_11 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(071),
         Q2 => DATA_FROM_ISERDES_TEMP(070),
         Q3 => DATA_FROM_ISERDES_TEMP(069),
         Q4 => DATA_FROM_ISERDES_TEMP(068),
         Q5 => DATA_FROM_ISERDES_TEMP(067),
         Q6 => DATA_FROM_ISERDES_TEMP(066),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_11,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(11),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_12 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(12);

   ISERDES_RX_DATA_12 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(077),
         Q2 => DATA_FROM_ISERDES_TEMP(076),
         Q3 => DATA_FROM_ISERDES_TEMP(075),
         Q4 => DATA_FROM_ISERDES_TEMP(074),
         Q5 => DATA_FROM_ISERDES_TEMP(073),
         Q6 => DATA_FROM_ISERDES_TEMP(072),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_12,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(12),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_13 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(13);

   ISERDES_RX_DATA_13 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(083),
         Q2 => DATA_FROM_ISERDES_TEMP(082),
         Q3 => DATA_FROM_ISERDES_TEMP(081),
         Q4 => DATA_FROM_ISERDES_TEMP(080),
         Q5 => DATA_FROM_ISERDES_TEMP(079),
         Q6 => DATA_FROM_ISERDES_TEMP(078),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_13,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(13),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_14 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(14);

   ISERDES_RX_DATA_14 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6,  
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(089),
         Q2 => DATA_FROM_ISERDES_TEMP(088),
         Q3 => DATA_FROM_ISERDES_TEMP(087),
         Q4 => DATA_FROM_ISERDES_TEMP(086),
         Q5 => DATA_FROM_ISERDES_TEMP(085),
         Q6 => DATA_FROM_ISERDES_TEMP(084),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_14,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(14),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   BITSLIP_15 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(15);

   ISERDES_RX_DATA_15 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_TEMP(095),
         Q2 => DATA_FROM_ISERDES_TEMP(094),
         Q3 => DATA_FROM_ISERDES_TEMP(093),
         Q4 => DATA_FROM_ISERDES_TEMP(092),
         Q5 => DATA_FROM_ISERDES_TEMP(091),
         Q6 => DATA_FROM_ISERDES_TEMP(090),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => BITSLIP_15,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY(15),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   

--MONITOR SIDE IODELAYS

   RX_MON_CE_00 <= ICE_DELAY OR ICE_TO_ISERDES(00) OR ICE_TO_MONITOR_RT(00);
   RX_MON_INC_00 <= INC_DELAY OR INC_TO_ISERDES(00) OR INC_TO_MONITOR_RT(00);
   RX_MON_RESET <= IDLY_RESET OR RESET;

   IODELAY_RX_MON_00 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(00),
         IDATAIN => DATA_RX_BUF_MON(00),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_00,
         INC => RX_MON_INC_00,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_01 <= ICE_DELAY OR ICE_TO_ISERDES(01) OR ICE_TO_MONITOR_RT(01);
  RX_MON_INC_01 <= INC_DELAY OR INC_TO_ISERDES(01) OR INC_TO_MONITOR_RT(01);

   IODELAY_RX_MON_01 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(01),
         IDATAIN => DATA_RX_BUF_MON(01),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_01,
         INC => RX_MON_INC_01,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_02 <= ICE_DELAY OR ICE_TO_ISERDES(02) OR ICE_TO_MONITOR_RT(02);
  RX_MON_INC_02 <= INC_DELAY OR INC_TO_ISERDES(02) OR INC_TO_MONITOR_RT(02);

   IODELAY_RX_MON_02 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(02),
         IDATAIN => DATA_RX_BUF_MON(02),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_02,
         INC => RX_MON_INC_02,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_03 <= ICE_DELAY OR ICE_TO_ISERDES(03) OR ICE_TO_MONITOR_RT(03);
  RX_MON_INC_03 <= INC_DELAY OR INC_TO_ISERDES(03) OR INC_TO_MONITOR_RT(03);

   IODELAY_RX_MON_03 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(03),
         IDATAIN => DATA_RX_BUF_MON(03),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_03,
         INC => RX_MON_INC_03,
        C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
   RX_MON_CE_04 <= ICE_DELAY OR ICE_TO_ISERDES(04) OR ICE_TO_MONITOR_RT(04);
   RX_MON_INC_04 <= INC_DELAY OR INC_TO_ISERDES(04) OR INC_TO_MONITOR_RT(04);

   IODELAY_RX_MON_04 : IODELAY 
    GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(04),
         IDATAIN => DATA_RX_BUF_MON(04),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_04,
         INC => RX_MON_INC_04,
        C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
   RX_MON_CE_05 <= ICE_DELAY OR ICE_TO_ISERDES(05) OR ICE_TO_MONITOR_RT(05);
   RX_MON_INC_05 <= INC_DELAY OR INC_TO_ISERDES(05) OR INC_TO_MONITOR_RT(05);

   IODELAY_RX_MON_05 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(05),
         IDATAIN => DATA_RX_BUF_MON(05),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_05,
         INC => RX_MON_INC_05,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_06 <= ICE_DELAY OR ICE_TO_ISERDES(06) OR ICE_TO_MONITOR_RT(06);
  RX_MON_INC_06 <= INC_DELAY OR INC_TO_ISERDES(06) OR INC_TO_MONITOR_RT(06);

   IODELAY_RX_MON_06 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(06),
         IDATAIN => DATA_RX_BUF_MON(06),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_06,
         INC => RX_MON_INC_06,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_07 <= ICE_DELAY OR ICE_TO_ISERDES(07) OR ICE_TO_MONITOR_RT(07);
  RX_MON_INC_07 <= INC_DELAY OR INC_TO_ISERDES(07) OR INC_TO_MONITOR_RT(07);

   IODELAY_RX_MON_07 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(07),
         IDATAIN => DATA_RX_BUF_MON(07),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_07,
         INC => RX_MON_INC_07,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_08 <= ICE_DELAY OR ICE_TO_ISERDES(08) OR ICE_TO_MONITOR_RT(08);
  RX_MON_INC_08 <= INC_DELAY OR INC_TO_ISERDES(08) OR INC_TO_MONITOR_RT(08);

   IODELAY_RX_MON_08 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(08),
         IDATAIN => DATA_RX_BUF_MON(08),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_08,
         INC => RX_MON_INC_08,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_09 <= ICE_DELAY OR ICE_TO_ISERDES(09) OR ICE_TO_MONITOR_RT(09);
  RX_MON_INC_09 <= INC_DELAY OR INC_TO_ISERDES(09) OR INC_TO_MONITOR_RT(09);

   IODELAY_RX_MON_09 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(09),
         IDATAIN => DATA_RX_BUF_MON(09),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_09,
         INC => RX_MON_INC_09,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_10 <= ICE_DELAY OR ICE_TO_ISERDES(10) OR ICE_TO_MONITOR_RT(10);
  RX_MON_INC_10 <= INC_DELAY OR INC_TO_ISERDES(10) OR INC_TO_MONITOR_RT(10);

   IODELAY_RX_MON_10 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(10),
         IDATAIN => DATA_RX_BUF_MON(10),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_10,
         INC => RX_MON_INC_10,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_11 <= ICE_DELAY OR ICE_TO_ISERDES(11) OR ICE_TO_MONITOR_RT(11);
  RX_MON_INC_11 <= INC_DELAY OR INC_TO_ISERDES(11) OR INC_TO_MONITOR_RT(11);

   IODELAY_RX_MON_11 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(11),
         IDATAIN => DATA_RX_BUF_MON(11),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_11,
         INC => RX_MON_INC_11,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_12 <= ICE_DELAY OR ICE_TO_ISERDES(12) OR ICE_TO_MONITOR_RT(12);
  RX_MON_INC_12 <= INC_DELAY OR INC_TO_ISERDES(12) OR INC_TO_MONITOR_RT(12);

   IODELAY_RX_MON_12 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(12),
         IDATAIN => DATA_RX_BUF_MON(12),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_12,
         INC => RX_MON_INC_12,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_13 <= ICE_DELAY OR ICE_TO_ISERDES(13) OR ICE_TO_MONITOR_RT(13);
  RX_MON_INC_13 <= INC_DELAY OR INC_TO_ISERDES(13) OR INC_TO_MONITOR_RT(13);

   IODELAY_RX_MON_13 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(13),
         IDATAIN => DATA_RX_BUF_MON(13),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_13,
         INC => RX_MON_INC_13,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
  RX_MON_CE_14 <= ICE_DELAY OR ICE_TO_ISERDES(14) OR ICE_TO_MONITOR_RT(14);
  RX_MON_INC_14 <= INC_DELAY OR INC_TO_ISERDES(14) OR INC_TO_MONITOR_RT(14);

   IODELAY_RX_MON_14 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(14),
         IDATAIN => DATA_RX_BUF_MON(14),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_14,
         INC => RX_MON_INC_14,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   
 RX_MON_CE_15 <= ICE_DELAY OR ICE_TO_ISERDES(15) OR ICE_TO_MONITOR_RT(15);
 RX_MON_INC_15 <= INC_DELAY OR INC_TO_ISERDES(15) OR INC_TO_MONITOR_RT(15);

   IODELAY_RX_MON_15 : IODELAY 
   GENERIC MAP(
      IDELAY_TYPE	=> "VARIABLE",
      IDELAY_VALUE	=> 0,
      ODELAY_VALUE	=> 0,
      REFCLK_FREQUENCY	=> 200.0,
      HIGH_PERFORMANCE_MODE => "TRUE"
       )
      PORT MAP (
         DATAOUT => DATA_RX_IDLY_MON(15),
         IDATAIN => DATA_RX_BUF_MON(15),
         ODATAIN => '0',
         DATAIN => '0',
         T => '1',
         CE => RX_MON_CE_15,
         INC => RX_MON_INC_15,
         C => RXCLKDIV_TEMP,
         RST => RX_MON_RESET);   
   

--MONITOR SIDE ISERDES                                                                                                    

   MON_BITSLIP_00 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(00);

   ISERDES_RX_MON_00 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(005),
         Q2 => DATA_FROM_ISERDES_MON(004),
         Q3 => DATA_FROM_ISERDES_MON(003),
         Q4 => DATA_FROM_ISERDES_MON(002),
         Q5 => DATA_FROM_ISERDES_MON(001),
         Q6 => DATA_FROM_ISERDES_MON(000),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_00,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(00),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_01 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(01);

   ISERDES_RX_MON_01 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(011),
         Q2 => DATA_FROM_ISERDES_MON(010),
         Q3 => DATA_FROM_ISERDES_MON(009),
         Q4 => DATA_FROM_ISERDES_MON(008),
         Q5 => DATA_FROM_ISERDES_MON(007),
         Q6 => DATA_FROM_ISERDES_MON(006),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_01,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(01),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_02 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(02);

   ISERDES_RX_MON_02 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(017),
         Q2 => DATA_FROM_ISERDES_MON(016),
         Q3 => DATA_FROM_ISERDES_MON(015),
         Q4 => DATA_FROM_ISERDES_MON(014),
         Q5 => DATA_FROM_ISERDES_MON(013),
         Q6 => DATA_FROM_ISERDES_MON(012),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_02,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(02),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_03 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(03);

   ISERDES_RX_MON_03 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(023),
         Q2 => DATA_FROM_ISERDES_MON(022),
         Q3 => DATA_FROM_ISERDES_MON(021),
         Q4 => DATA_FROM_ISERDES_MON(020),
         Q5 => DATA_FROM_ISERDES_MON(019),
         Q6 => DATA_FROM_ISERDES_MON(018),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_03,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(03),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_04 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(04);

   ISERDES_RX_MON_04 : ISERDES_NODELAY 
   GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(029),
         Q2 => DATA_FROM_ISERDES_MON(028),
         Q3 => DATA_FROM_ISERDES_MON(027),
         Q4 => DATA_FROM_ISERDES_MON(026),
         Q5 => DATA_FROM_ISERDES_MON(025),
         Q6 => DATA_FROM_ISERDES_MON(024),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_04,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(04),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
  MON_BITSLIP_05 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(05);

   ISERDES_RX_MON_05 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(035),
         Q2 => DATA_FROM_ISERDES_MON(034),
         Q3 => DATA_FROM_ISERDES_MON(033),
         Q4 => DATA_FROM_ISERDES_MON(032),
         Q5 => DATA_FROM_ISERDES_MON(031),
         Q6 => DATA_FROM_ISERDES_MON(030),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_05,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(05),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_06 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(06);

   ISERDES_RX_MON_06 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(041),
         Q2 => DATA_FROM_ISERDES_MON(040),
         Q3 => DATA_FROM_ISERDES_MON(039),
         Q4 => DATA_FROM_ISERDES_MON(038),
         Q5 => DATA_FROM_ISERDES_MON(037),
         Q6 => DATA_FROM_ISERDES_MON(036),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_06,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(06),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
  MON_BITSLIP_07 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(07);

   ISERDES_RX_MON_07 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(047),
         Q2 => DATA_FROM_ISERDES_MON(046),
         Q3 => DATA_FROM_ISERDES_MON(045),
         Q4 => DATA_FROM_ISERDES_MON(044),
         Q5 => DATA_FROM_ISERDES_MON(043),
         Q6 => DATA_FROM_ISERDES_MON(042),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_07,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(07),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_08 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(08);

   ISERDES_RX_MON_08 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(053),
         Q2 => DATA_FROM_ISERDES_MON(052),
         Q3 => DATA_FROM_ISERDES_MON(051),
         Q4 => DATA_FROM_ISERDES_MON(050),
         Q5 => DATA_FROM_ISERDES_MON(049),
         Q6 => DATA_FROM_ISERDES_MON(048),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_08,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(08),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
  MON_BITSLIP_09 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(09);

   ISERDES_RX_MON_09 : ISERDES_NODELAY 
      	 GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
         PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(059),
         Q2 => DATA_FROM_ISERDES_MON(058),
         Q3 => DATA_FROM_ISERDES_MON(057),
         Q4 => DATA_FROM_ISERDES_MON(056),
         Q5 => DATA_FROM_ISERDES_MON(055),
         Q6 => DATA_FROM_ISERDES_MON(054),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_09,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(09),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
  MON_BITSLIP_10 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(10);

   ISERDES_RX_MON_10 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(065),
         Q2 => DATA_FROM_ISERDES_MON(064),
         Q3 => DATA_FROM_ISERDES_MON(063),
         Q4 => DATA_FROM_ISERDES_MON(062),
         Q5 => DATA_FROM_ISERDES_MON(061),
         Q6 => DATA_FROM_ISERDES_MON(060),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_10,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(10),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_11 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(11);

   ISERDES_RX_MON_11 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(071),
         Q2 => DATA_FROM_ISERDES_MON(070),
         Q3 => DATA_FROM_ISERDES_MON(069),
         Q4 => DATA_FROM_ISERDES_MON(068),
         Q5 => DATA_FROM_ISERDES_MON(067),
         Q6 => DATA_FROM_ISERDES_MON(066),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_11,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(11),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
  MON_BITSLIP_12 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(12);

   ISERDES_RX_MON_12 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(077),
         Q2 => DATA_FROM_ISERDES_MON(076),
         Q3 => DATA_FROM_ISERDES_MON(075),
         Q4 => DATA_FROM_ISERDES_MON(074),
         Q5 => DATA_FROM_ISERDES_MON(073),
         Q6 => DATA_FROM_ISERDES_MON(072),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_12,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(12),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_13 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(13);

   ISERDES_RX_MON_13 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(083),
         Q2 => DATA_FROM_ISERDES_MON(082),
         Q3 => DATA_FROM_ISERDES_MON(081),
         Q4 => DATA_FROM_ISERDES_MON(080),
         Q5 => DATA_FROM_ISERDES_MON(079),
         Q6 => DATA_FROM_ISERDES_MON(078),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_13,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(13),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_14 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(14);

   ISERDES_RX_MON_14 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(089),
         Q2 => DATA_FROM_ISERDES_MON(088),
         Q3 => DATA_FROM_ISERDES_MON(087),
         Q4 => DATA_FROM_ISERDES_MON(086),
         Q5 => DATA_FROM_ISERDES_MON(085),
         Q6 => DATA_FROM_ISERDES_MON(084),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_14,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(14),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   
   MON_BITSLIP_15 <= BITSLIP_PULSE OR BITSLIP_TO_ISERDES(15);

   ISERDES_RX_MON_15 : ISERDES_NODELAY 
      GENERIC MAP(
         BITSLIP_ENABLE => TRUE, DATA_RATE => "DDR", DATA_WIDTH => 6, 
         INTERFACE_TYPE => "NETWORKING", NUM_CE => 1, SERDES_MODE =>"MASTER")   
      PORT MAP (
         Q1 => DATA_FROM_ISERDES_MON(095),
         Q2 => DATA_FROM_ISERDES_MON(094),
         Q3 => DATA_FROM_ISERDES_MON(093),
         Q4 => DATA_FROM_ISERDES_MON(092),
         Q5 => DATA_FROM_ISERDES_MON(091),
         Q6 => DATA_FROM_ISERDES_MON(090),
         SHIFTOUT1 => open,
         SHIFTOUT2 => open,
         BITSLIP => MON_BITSLIP_15,
         CE1 => '1',
         CE2 => '0',
         CLK => RXCLK_TEMP,
         CLKB => NOT RXCLK_TEMP,
         CLKDIV => RXCLKDIV_TEMP,
         D => DATA_RX_IDLY_MON(15),
         OCLK => '0',
         SHIFTIN1 => '0',
         SHIFTIN2 => '0',
         RST => RESET);   
   

END translated;
